@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2011.
+ * Copyright (c) Tony Bybell 1999-2012.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -2192,1174 +2192,3 @@ if(n->expansion)
 		}
 	}
 }
-
-/******************************************************************/
-
-/*
- * attempt to synthesize bitwise on loader fail...caller must free return pnt
- */
-static char *synth_blastvec(char *w)
-{
-char *mem = NULL;
-char *t;
-char *lbrack, *colon, *rbrack, *rname, *msbs, *lsbs;
-int wlen, bitlen, msb, lsb;
-int msbslen, lsbslen, maxnumlen;
-int i, siz;
-
-if(w)
-	{
-	if((lbrack = strrchr(w, '[')))
-	if((colon = strchr(lbrack+1, ':')))
-	if((rbrack = strchr(colon+1, ']')))
-		{
-		*lbrack = *colon = *rbrack = 0;
-		msbs = lbrack + 1;
-		lsbs = colon + 1;
-		rname = hier_extract(w, GLOBALS->hier_max_level);
-
-		msb = atoi(msbs);
-		lsb = atoi(lsbs);
-		bitlen = (msb > lsb) ? (msb - lsb + 1) : (lsb - msb + 1);
-		if(bitlen > 1)
-			{
-			wlen = strlen(w);
-
-			msbslen = strlen(msbs);
-			lsbslen = strlen(lsbs);
-			maxnumlen = (msbslen > lsbslen) ? msbslen : lsbslen;
-
-			siz = 	1 + 				/* # */
-				strlen(rname) +			/* vector alias name */
-				1+				/*   */
-				1+				/* [ */
-				msbslen+			/* msb */
-				1+				/* : */
-				lsbslen+			/* lsb */
-				1+				/* ] */
-				1;				/*   */
-
-			siz +=  bitlen * (
-				wlen +				/* full bitname */
-				1+				/* [ */
-				maxnumlen+			/* individual bit */
-				1+				/* ] */
-				1				/*   */
-				);
-
-			mem = calloc_2(1, siz);
-			t = mem + sprintf(mem, "#%s[%d:%d] ", rname, msb, lsb);
-			
-			if(msb > lsb)
-				{
-				for(i = msb; i >= lsb; i--)
-					{
-					t += sprintf(t, "%s[%d]", w, i);
-					if(i!=lsb) t += sprintf(t, " ");
-					}
-				}
-				else
-				{
-				for(i = msb; i <= lsb; i++)
-					{
-					t += sprintf(t, "%s[%d]", w, i);
-					if(i!=lsb) t += sprintf(t, " ");
-					}
-				}
-
-			/* fprintf(stderr, "%d,%d: %s\n", siz, strlen(mem), mem); */
-			}
-
-		}
-	}
-
-return(mem);
-}
-
-/******************************************************************/
-
-/*
- * Parse a line of the wave file and act accordingly.. 
- * Returns nonzero if trace(s) added.
- */
-int parsewavline(char *w, char *alias, int depth)
-{
-  int i;
-  int len;
-  char *w2;
-  nptr nexp;
-  unsigned int rows = 0;
-  char *prefix, *suffix, *new;
-  char *prefix_init, *w2_init;
-  unsigned int mode;
-
-  if(!(len=strlen(w))) return(0);
-  if(*(w+len-1)=='\n')
-    {
-      *(w+len-1)=0x00; /* strip newline if present */
-      len--;
-      if(!len) return(0);
-    }
-
-  while(1)
-    {
-      if(isspace((int)(unsigned char)*w)) { w++; continue; }
-      if(!(*w)) return(0);	/* no args */
-      break;			/* start grabbing chars from here */
-    }
-
-  w2=w;
-
-  /* sscanf(w2,"%s",prefix); */
-
- prefix=(char *)wave_alloca(len+1);
- suffix=(char *)wave_alloca(len+1);
- new=(char *)wave_alloca(len+1);
- memset(new, 0, len+1); /* scan-build */
-
- prefix_init = prefix;
- w2_init = new;
- mode = 0; /* 0 = before "{", 1 = after "{", 2 = after "}" or " " */
-
- while(*w2)
-   {
-     if((mode == 0) && (*w2 == '{'))
-       {
-	 mode = 1;
-	 w2++;
-       }
-     else if((mode == 1) && (*w2 == '}'))
-       {
-	 /* strcpy(prefix, ""); */
-	 *(prefix) = '\0';
-	 mode = 2;
-	 w2++;
-       }
-     else if((mode == 0) && (*w2 == ' '))
-       {
-	 /* strcpy(prefix, ""); */
-	 *(prefix) = '\0';
-	 strcpy(new, w2);
-	 mode = 2;
-	 w2++;
-	 new++;
-       }
-     else
-       {
-	 strcpy(new, w2);
-	 if (mode != 2)
-	   {
-	     strcpy(prefix, w2);
-	     prefix++;
-	   }
-	 w2++;
-	 new++;
-       }
-   }
-
- prefix = prefix_init;
- w2 = w2_init;
-
- /* printf("HHHHH |%s| %s\n", prefix, w2); */
-
-
-if(*w2=='*')
-	{
-	float f;
-	TimeType ttlocal;
-	int which=0;
-
-	GLOBALS->zoom_was_explicitly_set=~0;
-	w2++;
-
-	for(;;)
-		{
-		while(*w2==' ') w2++;
-		if(*w2==0) return(~0);
-
-		if(!which) { sscanf(w2,"%f",&f); GLOBALS->tims.zoom=(gdouble)f; }
-		else
-		{
-		sscanf(w2,TTFormat,&ttlocal);
-		switch(which)
-			{
-			case 1:  GLOBALS->tims.marker=ttlocal; break;
-			default: 
-				if((which-2)<26) GLOBALS->named_markers[which-2]=ttlocal; 
-				break;
-			}
-		}
-		which++;
-		w2++;
-		for(;;)
-			{
-			if(*w2==0) return(~0);
-			if(*w2=='\n') return(~0);
-			if(*w2!=' ') w2++; else break;
-			}
-		}
-	}
-else
-if(*w2=='-')
-	{
-	AddBlankTrace((*(w2+1)!=0)?(w2+1):NULL);
-	}
-else
-if(*w2=='>')
-	{
-	char *wnptr=(*(w2+1)!=0)?(w2+1):NULL;
-	GLOBALS->shift_timebase_default_for_add=wnptr?atoi_64(wnptr):LLDescriptor(0);
-	}
-else
-if(*w2=='@')
-	{
-	/* handle trace flags */
-	sscanf(w2+1, "%x", &GLOBALS->default_flags);
-	if( (GLOBALS->default_flags & (TR_FTRANSLATED|TR_PTRANSLATED)) == (TR_FTRANSLATED|TR_PTRANSLATED) )
-		{
-		GLOBALS->default_flags &= ~TR_PTRANSLATED; /* safest bet though this is a cfg file error */
-		}
-
-	return(~0);
-	}
-else
-if(*w2=='+')
-	{
-	/* handle aliasing */
-	  struct symbol *s;
-	  sscanf(w2+strlen(prefix),"%s",suffix);
-
-	  if(suffix[0]=='(')
-	    {
-	      for(i=1;;i++)
-		{
-		  if(suffix[i]==0) return(0);
-		  if((suffix[i]==')')&&(suffix[i+1])) {i++; break; }
-		}
-	      
-	      s=symfind(suffix+i, &rows);
-	      if (s) {
-		nexp = ExtractNodeSingleBit(&s->n[rows], atoi(suffix+1));
-		if(nexp)
-		  {
-		    AddNode(nexp, prefix+1);
-		    return(~0);
-		  }
-		else
-		  {
-		    return(0);
-		  }
-	      }	
-	      else 
-		{
-		char *lp = strrchr(suffix+i, '[');
-		if(lp)
-			{
-			char *ns = malloc_2(strlen(suffix+i) + 32);
-			char *colon = strchr(lp+1, ':');
-			int msi, lsi, bval, actual;
-			*lp = 0;
-
-			bval = atoi(suffix+1);
-			if(colon)
-				{
-				msi = atoi(lp+1);
-				lsi = atoi(colon+1);
-
-				if(lsi > msi)
-					{
-					actual = msi + bval;
-					}
-					else
-					{
-					actual = msi - bval;
-					}
-				}
-				else
-				{
-				actual = bval; /* punt */
-				}
-
-			sprintf(ns, "%s[%d]", suffix+i, actual);
-			*lp = '[';			
-
-			s=symfind(ns, &rows);
-			free_2(ns);
-			if(s)
-				{
-				AddNode(&s->n[rows], prefix+1);
-				return(~0);
-				}
-
-			}
-
-		  return(0);
-		}
-	    }
-	  else
-	    {
-	      int rc;
-	      
-	      char *newl   = strdup_2(w2+strlen(prefix));
-	      char *nalias = strdup_2(prefix+1);
-
-	      rc = parsewavline(newl, nalias, depth);
-	      if (newl)   free_2(newl);
-	      if (nalias) free_2(nalias);
-
-	      return rc;
-	    }
-	/* 	{ */
-/* 		if((s=symfind(suffix, &rows))) */
-/* 			{ */
-/* 			AddNode(&s->n[rows],prefix+1); */
-/* 			return(~0); */
-/* 			} */
-/* 			else */
-/* 			{ */
-/* 			return(0); */
-/* 			} */
-/* 		} */
-	}
-else
-if((*w2=='#')||(*w2==':'))
-	{
-	/* handle bitvec */
-	bvptr v=NULL;
-	bptr b=NULL;
-	int maketyp = (*w2=='#');
-
-	w2=w2+strlen(prefix);
-	while(1)
-		{
-		if(isspace((int)(unsigned char)*w2)) { w2++; continue; }
-		if(!(*w2)) return(0);	/* no more args */	
-		break;			/* start grabbing chars from here */
-		}
-
-	b = maketyp ? makevec(prefix+1,w2) : makevec_annotated(prefix+1,w2);	/* '#' vs ':' cases... */
-
-	if(b)
-		{
-		if((v=bits2vector(b)))
-			{
-			v->bits=b;	/* only needed for savefile function */
-			AddVector(v, alias);
-			free_2(b->name);
-			b->name=NULL;
-			return(v!=NULL);
-			}
-			else
-			{
-			free_2(b->name);
-			if(b->attribs) free_2(b->attribs);
-			free_2(b);
-			}
-		}
-		else if(!depth) /* don't try vectorized if we're re-entrant */
-		{
-		char *sp = strchr(w2, ' ');
-		char *lbrack;
-
-		if(sp)
-			{
-			*sp = 0;
-
-			lbrack = strrchr(w2, '[');
-
-			if(lbrack)
-				{
-				/* int made = 0; */ /* scan-build */
-				char *w3;
-				char *rbrack           = strrchr(w2,   ']');
-				char *rightmost_lbrack = strrchr(sp+1, '[');
-
-				if(rbrack && rightmost_lbrack)
-					{
-					*rbrack = 0;
-
-					w3 = malloc_2(strlen(w2) + 1 + strlen(rightmost_lbrack+1) + 1);
-					sprintf(w3, "%s:%s", w2, rightmost_lbrack+1);
-
-					/* made = */ maketraces(w3, alias, 1); /* scan-build */
-					free_2(w3);
-					}
-
-#if 0
-				/* this is overkill for now with possible delay implications so commented out */
-				if(!made)
-					{
-					*lbrack = 0;
-					fprintf(stderr, "GTKWAVE | Attempting regex '%s' on missing stranded vector\n", w2);
-
-					w3 = malloc_2(1 + strlen(w2) + 5);
-					sprintf(w3, "^%s\\[.*", w2);
-					maketraces(w3, alias, 1);
-					free_2(w3);
-					}
-#endif
-				}
-			}
-		}
-	
-	return(v!=NULL);
-	}
-else
-if(*w2=='!')
-	{
-	/* fill logical_mutex */
-	char ch;
-
-	for(i=0;i<6;i++)
-		{
-		ch = *(w2+i+1);
-		if(ch != 0)
-			{
-			if(ch=='!')
-				{
-				GLOBALS->strace_ctx->shadow_active = 0;
-				return(~0);
-				}
-
-			if((!i)&&(GLOBALS->strace_ctx->shadow_straces))
-				{
-				delete_strace_context();
-				}
-
-			GLOBALS->strace_ctx->shadow_logical_mutex[i] = (ch & 1);
-			}
-			else	/* in case of short read */
-			{
-			GLOBALS->strace_ctx->shadow_logical_mutex[i] = 0;
-			}
-		}
-
-	GLOBALS->strace_ctx->shadow_mark_idx_start = 0;
-	GLOBALS->strace_ctx->shadow_mark_idx_end = 0;
-
-	if(i==6)
-		{
-		ch = *(w2+7);
-		if(ch != 0)
-			{
-			if (isupper((int)(unsigned char)ch) || ch=='@')
-				GLOBALS->strace_ctx->shadow_mark_idx_start = ch - '@';
-		
-			ch = *(w2+8);
-			if(ch != 0)
-				{
-				if (isupper((int)(unsigned char)ch) || ch=='@')
-					GLOBALS->strace_ctx->shadow_mark_idx_end = ch - '@';
-				}
-			}
-		}
-
-	GLOBALS->strace_ctx->shadow_active = 1;
-	return(~0);
-	}
-	else
-if(*w2=='?')
-	{
-	/* fill st->type */
-	if(*(w2+1)=='\"')
-		{
-		int lens = strlen(w2+2);
-		if(GLOBALS->strace_ctx->shadow_string) free_2(GLOBALS->strace_ctx->shadow_string);
-		GLOBALS->strace_ctx->shadow_string=NULL;
-
-		if(lens)
-			{
-			GLOBALS->strace_ctx->shadow_string = malloc_2(lens+1);		
-			strcpy(GLOBALS->strace_ctx->shadow_string, w2+2);
-			}
-
-		GLOBALS->strace_ctx->shadow_type = ST_STRING;
-		}
-		else
-		{
-		unsigned int hex;
-		sscanf(w2+1, "%x", &hex);	
-		GLOBALS->strace_ctx->shadow_type = hex;
-		}
-
-	return(~0);
-	}
-else if(*w2=='^')
-	{
-	if(*(w2+1) == '>')
-		{
-		GLOBALS->current_translate_proc = 0;	/* will overwrite if loadable/translatable */
-
-		if(*(w2+2) != '0')
-			{
-			  /*			char *fn = strstr(w2+3, " "); */
-			char *fn = w2+3;
-			if(fn)
-				{
-				while(*fn && isspace((int)(unsigned char)*fn)) fn++;
-				if(*fn && !isspace((int)(unsigned char)*fn)) 
-					{
-					set_current_translate_proc(fn);
-					}
-				}
-			}
-		}
-	else
-	if(*(w2+1) == '<')
-		{
-		GLOBALS->current_translate_ttrans = 0;	/* will overwrite if loadable/translatable */
-
-		if(*(w2+2) != '0')
-			{
-			  /*			char *fn = strstr(w2+3, " "); */
-			char *fn = w2+3;
-			if(fn)
-				{
-				while(*fn && isspace((int)(unsigned char)*fn)) fn++;
-				if(*fn && !isspace((int)(unsigned char)*fn)) 
-					{
-					set_current_translate_ttrans(fn);
-					}
-				}
-			}
-		}
-		else
-		{
-		GLOBALS->current_translate_file = 0;	/* will overwrite if loadable/translatable */
-
-		if(*(w2+1) != '0')
-			{
-			char *fn = strstr(w2+2, " ");
-			if(fn)
-				{
-				while(*fn && isspace((int)(unsigned char)*fn)) fn++;
-				if(*fn && !isspace((int)(unsigned char)*fn)) 
-					{
-					set_current_translate_file(fn);
-					}
-				}
-			}
-		}
-	}
-else if (*w2 == '[')
-  {
-    /* Search for matching ']'.  */
-    w2++;
-    for (w = w2; *w; w++)
-      if (*w == ']')
-	break;
-    if (!*w)
-      return 0;
-    
-    *w++ = 0;
-    if (strcmp (w2, "size") == 0)
-      {
-      if(!GLOBALS->ignore_savefile_size)
-	{
-	/* Main window size.  */
-	int x, y;
-	sscanf (w, "%d %d", &x, &y);
-	if(!GLOBALS->block_xy_update) set_window_size (x, y);
-	}
-      }
-    else if (strcmp (w2, "pos") == 0)
-      {
-      if(!GLOBALS->ignore_savefile_pos)
-	{
-	/* Main window position.  */
-	int x, y;
-	sscanf (w, "%d %d", &x, &y);
-	if(!GLOBALS->block_xy_update) set_window_xypos (x, y);
-	}
-      }
-    else if (strcmp (w2, "color") == 0)
-      {
-      int which_col = 0;
-      sscanf (w, "%d", &which_col);
-      if((which_col>=0)&&(which_col<=WAVE_NUM_RAINBOW))
-		{
-		GLOBALS->which_t_color = which_col;
-		}
-		else
-		{
-		GLOBALS->which_t_color = 0;
-		}
-      }
-    else if (strcmp (w2, "pattern_trace") == 0)
-      {
-      int which_ctx = 0;
-      sscanf (w, "%d", &which_ctx);
-      if((which_ctx>=0)&&(which_ctx<WAVE_NUM_STRACE_WINDOWS))
-		{
-		GLOBALS->strace_ctx = &GLOBALS->strace_windows[GLOBALS->strace_current_window = which_ctx];
-		}
-      }
-    else if (strcmp (w2, "ruler") == 0)
-      {
-      GLOBALS->ruler_origin = GLOBALS->ruler_step = LLDescriptor(0);
-      sscanf(w, TTFormat" "TTFormat, &GLOBALS->ruler_origin, &GLOBALS->ruler_step);
-      }
-    else if (strcmp (w2, "timestart") == 0)
-      {
-      sscanf(w, TTFormat, &GLOBALS->timestart_from_savefile);
-      GLOBALS->timestart_from_savefile_valid = 1;
-      }
-#if WAVE_USE_GTK2
-    else if (strcmp (w2, "treeopen") == 0)
-	{
-	while(*w)
-		{
-		if(!isspace((int)(unsigned char)*w))
-			{
-			break;
-			}
-		w++;
-		}
-
-	if(GLOBALS->ctree_main)
-		{
-		force_open_tree_node(w);
-		}
-		else
-		{
-		/* cache values until ctree_main is created */
-		struct string_chain_t *t = calloc_2(1, sizeof(struct string_chain_t));
-		t->str = strdup_2(w);
-
-		if(!GLOBALS->treeopen_chain_curr)
-			{
-			GLOBALS->treeopen_chain_head = GLOBALS->treeopen_chain_curr = t;
-			}
-			else
-			{
-			GLOBALS->treeopen_chain_curr->next = t;
-			GLOBALS->treeopen_chain_curr = t;
-			}
-		}
-	}
-#endif
-    else if (strcmp (w2, "markername") == 0)
-	{
-	char *pnt = w;
-	int which;
-
-	if((*pnt) && (isspace((int)(unsigned char)*pnt))) pnt++;
-
-	if(*pnt)
-		{
-		which = (*pnt) - 'A';
-		if((which >=0) && (which <= 25))
-			{
-			pnt++;
-
-			if(*pnt)
-				{
-				if(GLOBALS->marker_names[which]) free_2(GLOBALS->marker_names[which]);
-				GLOBALS->marker_names[which] = strdup_2(pnt);
-				}
-			}
-		}
-	}
-    else
-      {
-	/* Unknown attribute.  Forget it.  */
-	return 0;
-      }
-  }
-	else
-	{
-	int rc = maketraces(w, alias, 0);
-	if(rc)
-		{
-		return(rc);
-		}
-		else
-		{
-		char *newl = synth_blastvec(w);
-
-		if(newl)
-			{
-			rc = parsewavline(newl, alias, depth+1);
-			free_2(newl);
-			}
-
-		return(rc);
-		}
-	}
-
-return(0);
-}
-
-
-/****************/
-/* LX2 variants */
-/****************/
-
-/*
- * Make solitary traces from wildcarded signals...
- */
-int maketraces_lx2(char *str, char *alias, int quick_return)
-{
-char *pnt, *wild;
-char ch, wild_active=0;
-int len;
-int i;
-int made = 0;
-
-pnt=str;
-while((ch=*pnt))
-	{
-	if(ch=='*') 
-		{
-		wild_active=1;
-		break;
-		}
-	pnt++;
-	}
-
-if(!wild_active)	/* short circuit wildcard evaluation with bsearch */
-	{
-	struct symbol *s;
-
-	if(str[0]=='(')
-		{
-		for(i=1;;i++)
-			{
-			if(str[i]==0) return(0);
-			if((str[i]==')')&&(str[i+1])) {i++; break; }
-			}
-
-		if((s=symfind(str+i, NULL)))
-			{
-			lx2_set_fac_process_mask(s->n);
-			made = ~0;
-			}
-		return(made);
-		}
-		else
-		{
-		if((s=symfind(str, NULL)))
-			{
-			lx2_set_fac_process_mask(s->n);
-			made = ~0;
-			}
-		return(made);
-		}
-	}
-
-while(1)
-{
-pnt=str;
-len=0;
-
-while(1)
-	{
-	ch=*pnt++;
-	if(isspace((int)(unsigned char)ch)||(!ch)) break;
-	len++;
-	}
-
-if(len)
-	{
-	wild=(char *)calloc_2(1,len+1);
-	memcpy(wild,str,len);
-	wave_regex_compile(wild, WAVE_REGEX_WILD);
-
-	for(i=0;i<GLOBALS->numfacs;i++)
-		{
-		if(wave_regex_match(GLOBALS->facs[i]->name, WAVE_REGEX_WILD))
-			{
-			lx2_set_fac_process_mask(GLOBALS->facs[i]->n);
-			made = ~0;
-			if(quick_return) break;
-			}
-		}
-
-	free_2(wild);
-	}
-
-if(!ch) break;
-str=pnt;
-}
-return(made);
-}
-
-
-/*
- * Create a vector from wildcarded signals...
- */
-int makevec_lx2(char *str)
-{
-char *pnt, *pnt2, *wild=NULL;
-char ch, ch2, wild_active;
-int len;
-int i;
-int rc = 0;
-
-while(1)
-{
-pnt=str;
-len=0;
-
-while(1)
-	{
-	ch=*pnt++;
-	if(isspace((int)(unsigned char)ch)||(!ch)) break;
-	len++;
-	}
-
-if(len)
-	{
-	wild=(char *)calloc_2(1,len+1);
-	memcpy(wild,str,len);
-
-	DEBUG(printf("WILD: %s\n",wild));
-
-	wild_active=0;
-	pnt2=wild;
-	while((ch2=*pnt2))
-		{
-		if(ch2=='*') 
-			{
-			wild_active=1;
-			break;
-			}
-		pnt2++;
-		}
-
-	if(!wild_active)	/* short circuit wildcard evaluation with bsearch */
-		{
-		struct symbol *s;
-		if(wild[0]=='(')
-			{
-			for(i=1;;i++)
-				{
-				if(wild[i]==0) break;
-				if((wild[i]==')')&&(wild[i+1])) 
-					{
-					i++; 
-					s=symfind(wild+i, NULL);
-					if(s)
-						{
-						lx2_set_fac_process_mask(s->n);
-						rc = 1;
-						}
-					break;
-					}
-				}
-			}
-			else
-			{
-			if((s=symfind(wild, NULL)))	
-				{
-				lx2_set_fac_process_mask(s->n);
-				rc = 1;
-				}
-			}
-		}
-		else
-		{
-		wave_regex_compile(wild, WAVE_REGEX_WILD);
-		for(i=GLOBALS->numfacs-1;i>=0;i--)	/* to keep vectors in little endian hi..lo order */
-			{
-			if(wave_regex_match(GLOBALS->facs[i]->name, WAVE_REGEX_WILD))
-				{
-				lx2_set_fac_process_mask(GLOBALS->facs[i]->n);
-				rc = 1;
-				}
-			}
-		}
-	free_2(wild);
-	}
-
-if(!ch) break;
-str=pnt;
-}
-
-return(rc);
-}
-
-
-/*
- * Parse a line of the wave file and act accordingly.. 
- * Returns nonzero if trace(s) added.
- */
-int parsewavline_lx2(char *w, char *alias, int depth)
-{
-  int made = 0;
-  int i;
-  int len;
-  char *w2;
-  char *prefix, *suffix, *new;
-  char *prefix_init, *w2_init;
-  unsigned int mode;
-
-
-  if(!(len=strlen(w))) return(0);
-  if(*(w+len-1)=='\n')
-    {
-      *(w+len-1)=0x00; /* strip newline if present */
-      len--;
-      if(!len) return(0);
-    }
-
-  while(1)
-    {
-      if(isspace((int)(unsigned char)*w)) { w++; continue; }
-      if(!(*w)) return(0);	/* no args */
-      break;			/* start grabbing chars from here */
-    }
-
-  w2=w;
-
-/* sscanf(w2,"%s",prefix); */
-
- prefix=(char *)wave_alloca(len+1);
- suffix=(char *)wave_alloca(len+1);
- new=(char *)wave_alloca(len+1);
- new[0] = 0; /* scan-build : in case there are weird mode problems */
-
- prefix_init = prefix;
- w2_init = new;
- mode = 0; /* 0 = before "{", 1 = after "{", 2 = after "}" or " " */
-
- while(*w2)
-   {
-     if((mode == 0) && (*w2 == '{'))
-       {
-	 mode = 1;
-	 w2++;
-       }
-     else if((mode == 1) && (*w2 == '}'))
-       {
-
-	 *(prefix) = '\0';
-	 mode = 2;
-	 w2++;
-       }
-     else if((mode == 0) && (*w2 == ' '))
-       {
-	 *(prefix) = '\0';
-	 strcpy(new, w2);
-	 mode = 2;
-	 w2++;
-	 new++;
-       }
-     else
-       {
-	 strcpy(new, w2);
-	 if (mode != 2)
-	   {
-	     strcpy(prefix, w2);
-	     prefix++;
-	   }
-	 w2++;
-	 new++;
-       }
-   }
-
- prefix = prefix_init;
- w2 = w2_init;
-
- /* printf("IIIII |%s| %s\n", prefix, w2); */
-
-if(*w2=='[')
-	{
-	}
-else
-if(*w2=='*')
-	{
-	}
-else
-if(*w2=='-')
-	{
-	}
-else
-if(*w2=='>')
-	{
-	}
-else
-if(*w2=='@')
-	{
-	}
-else
-if(*w2=='+')
-	{
-	/* handle aliasing */
-	struct symbol *s;
-	sscanf(w2+strlen(prefix),"%s",suffix);
-
-	if(suffix[0]=='(')
-		{
-		for(i=1;;i++)
-			{
-			if(suffix[i]==0) return(0);
-			if((suffix[i]==')')&&(suffix[i+1])) {i++; break; }
-			}
-
-		s=symfind(suffix+i, NULL);
-		if(s)
-			{
-			lx2_set_fac_process_mask(s->n);
-			made = ~0;
-			}
-                else
-                        {
-                        char *lp = strrchr(suffix+i, '[');
-			if(lp)
-				{
-				char *ns = malloc_2(strlen(suffix+i) + 32);
-				char *colon = strchr(lp+1, ':');
-				int msi, lsi, bval, actual;
-				*lp = 0;
-
-				bval = atoi(suffix+1);
-				if(colon)
-					{
-					msi = atoi(lp+1);
-					lsi = atoi(colon+1);
-	
-					if(lsi > msi)
-						{
-						actual = msi + bval;
-						}
-						else
-						{
-						actual = msi - bval;
-						}
-					}
-					else
-					{
-					actual = bval; /* punt */
-					}
-
-				sprintf(ns, "%s[%d]", suffix+i, actual);
-				*lp = '[';			
-
-				s=symfind(ns, NULL);
-				free_2(ns);
-				if(s)
-					{
-	                                lx2_set_fac_process_mask(s->n);
-	                                made = ~0;
-					}
-				}
-			}
-
-		return(made);
-		}
-	else
-	  {
-	    int rc;
-	    char *newl   = strdup_2(w2+strlen(prefix));
-	    char *nalias = strdup_2(prefix+1);
-
-	    rc = parsewavline_lx2(newl, nalias, depth);
-	    if (newl)   free_2(newl);
-	    if (nalias) free_2(nalias);
-
-	    return rc;
-	  }
-
-	/* 	{ */
-/* 		if((s=symfind(suffix, NULL))) */
-/* 			{ */
-/* 			lx2_set_fac_process_mask(s->n); */
-/* 			made = ~0; */
-/* 			} */
-/* 		return(made); */
-/* 		} */
-	}
-else
-if((*w2=='#')||(*w2==':'))
-	{
-	int rc;
-
-	/* handle bitvec, parsing extra time info and such is inefficient but ok for ":" case */
-	w2=w2+strlen(prefix);
-	while(1)
-		{
-		if(isspace((int)(unsigned char)*w2)) { w2++; continue; }
-		if(!(*w2)) return(0);	/* no more args */	
-		break;			/* start grabbing chars from here */
-		}
-
-	rc = makevec_lx2(w2);
-	if((!rc)&&(!depth))		/* don't try vectorized if we're re-entrant */
-		{
-		char *sp = strchr(w2, ' ');
-		char *lbrack;
-
-		if(sp)
-			{
-			*sp = 0;
-
-			lbrack = strrchr(w2, '[');
-
-			if(lbrack)
-				{
-				char *w3;
-				char *rbrack           = strrchr(w2,   ']');
-				char *rightmost_lbrack = strrchr(sp+1, '[');
-
-				if(rbrack && rightmost_lbrack)
-					{
-					*rbrack = 0;
-
-					w3 = malloc_2(strlen(w2) + 1 + strlen(rightmost_lbrack+1) + 1);
-					sprintf(w3, "%s:%s", w2, rightmost_lbrack+1);
-
-					made = maketraces_lx2(w3, alias, 1);
-					free_2(w3);
-					}
-
-				if(0)	/* this is overkill for now with possible delay implications so commented out */
-				if(!made)
-					{
-					*lbrack = 0;
-
-					w3 = malloc_2(1 + strlen(w2) + 5);
-					sprintf(w3, "^%s\\[.*", w2);
-					maketraces_lx2(w3, alias, 1);
-					free_2(w3);
-					}
-				}
-			}
-		}
-
-	return(made);
-	}
-else
-if(*w2=='!')
-	{
-	}
-	else
-if(*w2=='?')
-	{
-	}
-else if(*w2=='^')
-	{
-	}
-	else
-	{
-	  made = maketraces_lx2(w, alias, 0);
-        if(!made)
-                {
-                char *newl = synth_blastvec(w);
-
-		if(newl)
-			{
-	                made = parsewavline_lx2(newl, alias, depth+1);
-	                free_2(newl);
-			}
-                }
-	}
-
-return(made);
-}
-
-
-/****************/
-/* LX2 variants */
-/****************/
-
