@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2010
+ * Copyright (c) Tony Bybell 1999-2012
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -14,6 +14,9 @@
  * malloc tracking added on 05aug07ajb for 3.1 series
  */
 #include <config.h>
+#include <stdio.h>
+#include <stdlib.h>
+#include <string.h>
 #include "globals.h"
 #include "debug.h"
 #ifdef _WAVE_HAVE_JUDY
@@ -569,3 +572,37 @@ return(tmpspace);
 #endif
 }
 
+
+void wave_gtk_window_set_title(GtkWindow *window, const gchar *title, int typ, int pct)
+{
+if(window && title)
+	{
+	switch(typ)
+		{
+		case WAVE_SET_TITLE_MODIFIED:
+			{
+			const char *pfx = "[Modified] ";
+			char *t = wave_alloca(strlen(pfx) + strlen(title) + 1);
+	
+			strcpy(t, pfx);
+			strcat(t, title);
+			gtk_window_set_title(window, t);
+			}
+			break;
+
+		case WAVE_SET_TITLE_LOADING:
+			{
+			char *t = wave_alloca(64 + strlen(title) + 1); /* make extra long */
+	
+			sprintf(t, "[Loading %d%%] %s", pct, title);
+			gtk_window_set_title(window, t);
+			}
+			break;
+
+		case WAVE_SET_TITLE_NONE:
+		default:		
+			gtk_window_set_title(window, title);
+			break;
+		}
+	}
+}
