@@ -18,10 +18,6 @@
 #include <stdlib.h>
 #include <fnmatch.h>
 
-#ifdef __linux__
-extern char *canonicalize_file_name (__const char *__name);
-#endif
-
 #if GTK_CHECK_VERSION(2,4,0)
 
 static gboolean ffunc (const GtkFileFilterInfo *filter_info, gpointer data)
@@ -114,7 +110,7 @@ if((alloclen=strlen(allocbuf)))
 	}
 
 DEBUG(printf("Filesel OK %s\n",allocbuf));
-gtk_grab_remove(GLOBALS->fs_file_c_1);
+wave_gtk_grab_remove(GLOBALS->fs_file_c_1);
 gtk_widget_destroy(GLOBALS->fs_file_c_1);
 gtkwave_main_iteration();
 GLOBALS->cleanup_file_c_2();
@@ -123,7 +119,7 @@ GLOBALS->cleanup_file_c_2();
 static void cancel_callback(GtkWidget *widget, GtkWidget *nothing)
 {
 DEBUG(printf("Filesel Entry Cancel\n"));
-gtk_grab_remove(GLOBALS->fs_file_c_1);
+wave_gtk_grab_remove(GLOBALS->fs_file_c_1);
 gtk_widget_destroy(GLOBALS->fs_file_c_1);
 gtkwave_main_iteration();
 if(GLOBALS->bad_cleanup_file_c_1) GLOBALS->bad_cleanup_file_c_1();
@@ -156,7 +152,7 @@ if(*GLOBALS->fileselbox_text) gtk_file_selection_set_filename(GTK_FILE_SELECTION
  */
 
 gtk_widget_show(GLOBALS->fs_file_c_1);
-gtk_grab_add(GLOBALS->fs_file_c_1);
+wave_gtk_grab_add(GLOBALS->fs_file_c_1);
 }
 
 
@@ -171,6 +167,7 @@ GtkWidget *label;
 GtkWidget *label_ent;
 GtkWidget *box;
 GtkTooltips *tooltips;
+struct Global *old_globals = GLOBALS;
 #endif
 
 if(!*filesel_path) /* if no name specified, hijack loaded file name path */
@@ -230,19 +227,6 @@ GLOBALS->filesel_ok=0;
 
 if(*GLOBALS->fileselbox_text && (!g_path_is_absolute(*GLOBALS->fileselbox_text)))
 	{
-#ifdef __linux__
-	char *can = canonicalize_file_name(*GLOBALS->fileselbox_text);
-
-	if(can)
-		{
-		if(*GLOBALS->fileselbox_text) free_2(*GLOBALS->fileselbox_text);
-	        *GLOBALS->fileselbox_text=(char *)malloc_2(strlen(can)+1);
-	        strcpy(*GLOBALS->fileselbox_text, can);
-		free(can);
-		can_set_filename = 1;
-		}
-
-#else
 #if defined __USE_BSD || defined __USE_XOPEN_EXTENDED || defined __CYGWIN__ || defined HAVE_REALPATH
 	char *can = realpath(*GLOBALS->fileselbox_text, NULL);
 
@@ -258,7 +242,6 @@ if(*GLOBALS->fileselbox_text && (!g_path_is_absolute(*GLOBALS->fileselbox_text))
 #if __GNUC__
 #warning Absolute file path warnings might be issued by the file chooser dialogue on this system!
 #endif
-#endif
 #endif
 	}
 	else
@@ -335,10 +318,23 @@ gtk_file_chooser_set_extra_widget(GTK_FILE_CHOOSER(pFileChoose), box);
 
 if(pattn)
 	{
+	int is_gtkw = suffix_check(pattn, ".gtkw");
+	int is_sav = suffix_check(pattn, ".sav");
+
 	filter = gtk_file_filter_new();
 	gtk_file_filter_add_pattern(filter, pattn);
 	gtk_file_filter_set_name(filter, pattn);
 	gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(pFileChoose), filter);
+
+	if(is_gtkw || is_sav)
+		{
+		const char *pattn2 = is_sav ? "*.gtkw" : "*.sav";
+
+		filter = gtk_file_filter_new();
+		gtk_file_filter_add_pattern(filter, pattn2);
+		gtk_file_filter_set_name(filter, pattn2);
+		gtk_file_chooser_add_filter(GTK_FILE_CHOOSER(pFileChoose), filter);
+		}
 	}
 
 if((!pattn)  || (strcmp(pattn, "*")))
@@ -371,9 +367,12 @@ if(pWindowMain)
 	gtk_window_set_transient_for(GTK_WINDOW(pFileChoose), GTK_WINDOW(pWindowMain));
 	}
 gtk_widget_show(pFileChoose);
-gtk_grab_add(pFileChoose);
+wave_gtk_grab_add(pFileChoose);
 
-if (gtk_dialog_run(GTK_DIALOG (pFileChoose)) == GTK_RESPONSE_ACCEPT)
+/* check against old_globals is because of DnD context swapping so make response fail */
+
+if((gtk_dialog_run(GTK_DIALOG (pFileChoose)) == GTK_RESPONSE_ACCEPT) && 
+		(GLOBALS == old_globals) && (GLOBALS->fileselbox_text))
 	{
 	G_CONST_RETURN char *allocbuf;
 	int alloclen;
@@ -381,7 +380,10 @@ if (gtk_dialog_run(GTK_DIALOG (pFileChoose)) == GTK_RESPONSE_ACCEPT)
 	allocbuf = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (pFileChoose));
 	if((alloclen=strlen(allocbuf)))
 	        {
+		int gtkw_test = 0;
+
 	        GLOBALS->filesel_ok=1;
+
 	        if(*GLOBALS->fileselbox_text) free_2(*GLOBALS->fileselbox_text);
 	        *GLOBALS->fileselbox_text=(char *)malloc_2(alloclen+1);
 	        strcpy(*GLOBALS->fileselbox_text, allocbuf);
@@ -393,6 +395,7 @@ if (gtk_dialog_run(GTK_DIALOG (pFileChoose)) == GTK_RESPONSE_ACCEPT)
 			char *s2;
 			char *suffix = wave_alloca(strlen(pattn) + 1);					
 			char *term;
+			int attempt_suffix = 1;
 
 			strcpy(suffix, pattn);
 			while((*suffix) && (*suffix != '.')) suffix++;
@@ -400,27 +403,43 @@ if (gtk_dialog_run(GTK_DIALOG (pFileChoose)) == GTK_RESPONSE_ACCEPT)
 			while((*term) && (isalnum((int)(unsigned char)*term))) term++;
 			*term = 0;
 
-                        if(strlen(s) > strlen(suffix))
-                                {
-                                if(strcmp(s + strlen(s) - strlen(suffix), suffix))
-                                        {
-                                        goto fix_suffix;
-                                        }
-                                }
-                                else
-                                {
-fix_suffix:                     s2 = malloc_2(strlen(s) + strlen(suffix) + 1);
-                                strcpy(s2, s);
-                                strcat(s2, suffix);
-                                free_2(s);
-				*GLOBALS->fileselbox_text = s2;
-                                }
+			gtkw_test = suffix_check(pattn, ".gtkw") || suffix_check(pattn, ".sav");
+
+			if(gtkw_test)
+				{
+				attempt_suffix = (!suffix_check(s, ".gtkw")) && (!suffix_check(s, ".sav"));
+				}
+
+			if(attempt_suffix)
+				{
+	                        if(strlen(s) > strlen(suffix))
+	                                {
+	                                if(strcmp(s + strlen(s) - strlen(suffix), suffix))
+	                                        {
+	                                        goto fix_suffix;
+	                                        }
+	                                }
+	                                else
+	                                {
+fix_suffix: 	                    	s2 = malloc_2(strlen(s) + strlen(suffix) + 1);
+	                                strcpy(s2, s);
+	                                strcat(s2, suffix);
+	                                free_2(s);
+					*GLOBALS->fileselbox_text = s2;
+	                                }
+				}
+			}
+
+		if((gtkw_test) && (*GLOBALS->fileselbox_text))
+			{
+			GLOBALS->is_gtkw_save_file = suffix_check(*GLOBALS->fileselbox_text, ".gtkw");
 			}
 	        }
 
 	DEBUG(printf("Filesel OK %s\n",allocbuf));
-	gtk_grab_remove(pFileChoose);
+	wave_gtk_grab_remove(pFileChoose);
 	gtk_widget_destroy(pFileChoose);
+	GLOBALS->pFileChoose = NULL; /* keeps DND from firing */
 
 	gtkwave_main_iteration();
 	ok_func();
@@ -428,8 +447,9 @@ fix_suffix:                     s2 = malloc_2(strlen(s) + strlen(suffix) + 1);
 	else
 	{
 	DEBUG(printf("Filesel Entry Cancel\n"));
-	gtk_grab_remove(pFileChoose);
+	wave_gtk_grab_remove(pFileChoose);
 	gtk_widget_destroy(pFileChoose);
+	GLOBALS->pFileChoose = NULL; /* keeps DND from firing */
 
 	gtkwave_main_iteration();
 	if(GLOBALS->bad_cleanup_file_c_1) notok_func();
