@@ -464,6 +464,8 @@ NULL, /* lastchange */
 /* 
  * main.c
  */
+1, /* is_gtkw_save_file */
+0, /* dumpfile_is_modified */
 NULL, /* missing_file_toolbar */
 NULL, /* argvlist */
 #if defined(HAVE_LIBTCL)
@@ -498,12 +500,14 @@ NULL, /* dual_ctx 196 */
 0, /* dual_id 197 */
 0, /* dual_attach_id_main_c_1 198 */
 0, /* dual_race_lock 199 */
-NULL, /* rpc_ctx */
-0, /* rpc_id */
 NULL, /* mainwindow 200 */
 NULL, /* signalwindow 201 */
 NULL, /* wavewindow 202 */
 NULL, /* toppanedwindow 203 */
+NULL, /* panedwindow */
+0, /* toppanedwindow_size_cache */
+0, /* panedwindow_size_cache */
+0, /* vpanedwindow_size_cache */
 NULL, /* sstpane 204 */
 NULL, /* expanderwindow 205 */
 0, /* disable_window_manager 206 */
@@ -559,10 +563,14 @@ NULL, /* cleanup_markerbox_c_4 233 */
  */ 
 NULL, /* cutcopylist */
 0, /* enable_fast_exit 236 */
+0, /* quiet_checkmenu */
 NULL, /* wave_script_args 237 */
+0, /* ignore_savefile_pane_pos */
 0, /* ignore_savefile_pos 238 */
 0, /* ignore_savefile_size 239 */
+#ifndef WAVE_USE_MLIST_T
 NULL, /* item_factory_menu_c_1 241 */
+#endif
 NULL, /* regexp_string_menu_c_1 242 */
 NULL, /* trace_to_alias_menu_c_1 243 */
 NULL, /* showchangeall_menu_c_1 244 */
@@ -714,10 +722,17 @@ NULL, /* filesel_print_ps_renderopt_c_1 325 */
 NULL, /* filesel_print_mif_renderopt_c_1 326 */
 {0,0,0}, /* target_mutex_renderopt_c_1 328 */
 {0,0,0,0,0}, /* page_mutex_renderopt_c_1 330 */
-{0,0}, /* render_mutex_renderopt_c_1 332 */
+{0,0,0}, /* render_mutex_renderopt_c_1 332 */
 0, /* page_size_type_renderopt_c_1 333 */
 
 
+/*
+ * savefile.c
+ */
+NULL, /* sfn */
+NULL, /* lcname */
+
+
 /*
  * search.c
  */
@@ -769,6 +784,9 @@ NULL, /* tcache_showchange_c_1 367 */
 NULL, /* signalarea 369 */
 NULL, /* signalfont 370 */
 NULL, /* signalpixmap 371 */
+#ifdef WAVE_ALLOW_QUARTZ_FLUSH_WORKAROUND
+0, /* force_hide_show */
+#endif
 0, /* max_signal_name_pixel_width 372 */
 0, /* signal_pixmap_width 373 */
 0, /* signal_fill_width 374 */
@@ -806,6 +824,8 @@ NULL, /* cleanup 386 */
 /*
  * splash.c
  */ 
+0, /* splash_is_loading */
+0, /* splash_fix_win_title */
 1, /* splash_disable 387 */
 NULL, /* wave_splash_pixmap 389 */
 NULL, /* wave_splash_mask 390 */
@@ -959,7 +979,7 @@ NULL, /* void (*cleanup_treesearch_gtk1_c)(); */
 /*
  * treesearch_gtk2.c
  */
-#ifdef WAVE_GDK_QUARTZ
+#ifdef MAC_INTEGRATION
 NULL, /* dnd_helper_quartz */
 #endif
 NULL, /* treeopen_chain_head */
@@ -1315,7 +1335,7 @@ static void widget_ungrab_destroy(GtkWidget **wp)
 {
 if(*wp)
 	{
-	gtk_grab_remove(*wp);
+	wave_gtk_grab_remove(*wp);
 	gtk_widget_destroy(*wp);
 	*wp = NULL;
 	}
@@ -1331,13 +1351,132 @@ if(*wp)
 }
 
 
+/*
+ * setjump to avoid -Wclobbered issues
+ */
+static int handle_setjmp(void)
+{
+struct Global *setjmp_globals;
+int load_was_success = 0;
+
+GLOBALS->vcd_jmp_buf = calloc(1, sizeof(jmp_buf));
+setjmp_globals =  calloc(1,sizeof(struct Global));      /* allocate yet another copy of viewer context */
+memcpy(setjmp_globals, GLOBALS, sizeof(struct Global));	/* clone */
+GLOBALS->alloc2_chain = NULL;				/* will merge this in after load if successful */
+GLOBALS->outstanding = 0;				/* zero out count of chunks in this ctx */
+
+if(!setjmp(*(GLOBALS->vcd_jmp_buf)))			/* loader exception handling */
+	{
+	switch(GLOBALS->loaded_file_type)		/* on fail, longjmp called in these loaders */
+		{			
+   		case LXT_FILE: lxt_main(GLOBALS->loaded_file_name); break;
+   		case VCD_FILE: vcd_main(GLOBALS->loaded_file_name); break;
+		case VCD_RECODER_FILE: vcd_recoder_main(GLOBALS->loaded_file_name); break;
+		default: break;
+		}
+	
+#ifdef _WAVE_HAVE_JUDY
+	{
+	Pvoid_t  PJArray = (Pvoid_t)setjmp_globals->alloc2_chain;
+	int rcValue;
+	Word_t Index;
+
+	Index = 0;
+	for (rcValue = Judy1First(PJArray, &Index, PJE0); rcValue != 0; rcValue = Judy1Next(PJArray, &Index, PJE0))
+		{
+	        Judy1Set ((Pvoid_t)&GLOBALS->alloc2_chain, Index, PJE0);
+		}
+
+	GLOBALS->outstanding += setjmp_globals->outstanding;
+	Judy1FreeArray(&PJArray, PJE0);
+	}
+#else
+	{
+	void **t, **t2;
+
+	t = (void **)setjmp_globals->alloc2_chain;
+	while(t)
+		{
+		t2 = (void **) *(t+1);
+		if(t2)
+			{
+			t = t2;
+			}
+			else
+			{
+			*(t+1) = GLOBALS->alloc2_chain;
+			if(GLOBALS->alloc2_chain)
+				{
+				t2 = (void **)GLOBALS->alloc2_chain;
+				*(t2+0) = t;
+				}
+			GLOBALS->alloc2_chain = setjmp_globals->alloc2_chain;
+			GLOBALS->outstanding += setjmp_globals->outstanding;
+			break;					
+			}
+		}
+	}
+#endif
+	free(GLOBALS->vcd_jmp_buf); GLOBALS->vcd_jmp_buf = NULL;
+	free(setjmp_globals); setjmp_globals = NULL;
+
+	load_was_success = 1;
+	}
+	else
+	{
+	free(GLOBALS->vcd_jmp_buf); GLOBALS->vcd_jmp_buf = NULL;
+	if(GLOBALS->vcd_handle_vcd_c_1)
+		{
+		if(GLOBALS->vcd_is_compressed_vcd_c_1)
+		        {
+		        pclose(GLOBALS->vcd_handle_vcd_c_1);
+		        GLOBALS->vcd_handle_vcd_c_1 = NULL;
+		        }
+		        else
+		        {
+		        fclose(GLOBALS->vcd_handle_vcd_c_1);
+		        GLOBALS->vcd_handle_vcd_c_1 = NULL;
+		        }
+		}
+	if(GLOBALS->vcd_handle_vcd_recoder_c_2)
+		{
+		if(GLOBALS->vcd_is_compressed_vcd_recoder_c_2)
+	        				{
+	        				pclose(GLOBALS->vcd_handle_vcd_recoder_c_2);
+	        				GLOBALS->vcd_handle_vcd_recoder_c_2 = NULL;
+	        				}    
+	        				else
+	        				{
+	        				fclose(GLOBALS->vcd_handle_vcd_recoder_c_2);
+	        				GLOBALS->vcd_handle_vcd_recoder_c_2 = NULL;
+	        				}
+		}
+
+
+	if(GLOBALS->vlist_handle) { fclose(GLOBALS->vlist_handle); GLOBALS->vlist_handle = NULL; }
+	if(GLOBALS->mm_lxt_mmap_addr)
+		{                        
+		munmap(GLOBALS->mm_lxt_mmap_addr, GLOBALS->mm_lxt_mmap_len); 
+		GLOBALS->mm_lxt_mmap_addr = NULL;
+		}                        
+	free_outstanding(); /* free anything allocated in loader ctx */
+
+	memcpy(GLOBALS, setjmp_globals, sizeof(struct Global)); /* copy over old ctx */
+	free(setjmp_globals);					/* remove cached old ctx */
+	/* now try again, jump through recovery sequence below */
+	}
+
+return(load_was_success);
+}
+
+
 /*
  * reload from old into the new context
  */
-void reload_into_new_context(void)
+void reload_into_new_context_2(void)
 {
  FILE *statefile;
- struct Global *new_globals, *setjmp_globals;
+ struct Global *new_globals;
  /* gint tree_frame_x = -1; */ /* scan-build */
  gint tree_frame_y = -1;
  gdouble tree_vadj_value = 0.0;
@@ -1356,6 +1495,7 @@ void reload_into_new_context(void)
  int s_ctx_iter;
 
  /* save these in case we decide to write out the rc file later as a user option */
+ char cached_ignore_savefile_pane_pos = GLOBALS->ignore_savefile_pane_pos;
  char cached_ignore_savefile_pos = GLOBALS->ignore_savefile_pos;
  char cached_ignore_savefile_size = GLOBALS->ignore_savefile_size;
  char cached_splash_disable = GLOBALS->splash_disable;
@@ -1369,12 +1509,14 @@ void reload_into_new_context(void)
  logbox_reload();
 
  /* let all GTK/X events spin through in order to keep menus from freezing open during reload */
+#ifndef MAC_INTEGRATION
  if(GLOBALS->text_status_c_2)
 	{
-	gtk_grab_add(GLOBALS->text_status_c_2);			/* grab focus to a known widget with no real side effects */
+	wave_gtk_grab_add(GLOBALS->text_status_c_2);		/* grab focus to a known widget with no real side effects */
 	gtkwave_main_iteration();				/* spin on GTK event loop */
-	gtk_grab_remove(GLOBALS->text_status_c_2);		/* ungrab focus */
+	wave_gtk_grab_remove(GLOBALS->text_status_c_2);		/* ungrab focus */
 	}
+#endif
 
  printf("GTKWAVE | Reloading waveform...\n");
  gtkwavetcl_setvar(WAVE_TCLCB_RELOAD_BEGIN, GLOBALS->loaded_file_name, WAVE_TCLCB_RELOAD_BEGIN_FLAGS); 
@@ -1391,7 +1533,7 @@ void reload_into_new_context(void)
    return;
  }
  if(fd_dummy >=0) close(fd_dummy);
- write_save_helper(statefile);
+ write_save_helper(save_tmpfilename, statefile);
  fclose(statefile);
 
  reload_tmpfilename = strdup(save_tmpfilename);
@@ -1496,6 +1638,7 @@ void reload_into_new_context(void)
  new_globals->signalwindow = GLOBALS->signalwindow; 
  new_globals->wavewindow = GLOBALS->wavewindow;
  new_globals->toppanedwindow = GLOBALS->toppanedwindow;
+ new_globals->panedwindow = GLOBALS->panedwindow;
  new_globals->sstpane = GLOBALS->sstpane;
  new_globals->sst_vpaned = GLOBALS->sst_vpaned;
  new_globals->expanderwindow = GLOBALS->expanderwindow;
@@ -1568,6 +1711,7 @@ void reload_into_new_context(void)
  new_globals->context_tabposition = GLOBALS->context_tabposition;
  new_globals->use_standard_clicking = GLOBALS->use_standard_clicking;
 
+ new_globals->ignore_savefile_pane_pos = 1; /* to keep window from resizing/jumping */
  new_globals->ignore_savefile_pos = 1; /* to keep window from resizing/jumping */
  new_globals->ignore_savefile_size = 1; /* to keep window from resizing/jumping */
 
@@ -1694,13 +1838,17 @@ void reload_into_new_context(void)
  strcpy2_into_new_context(new_globals, &new_globals->skip_end, &GLOBALS->skip_end);
 
  /* main.c */
+ new_globals->missing_file_toolbar = GLOBALS->missing_file_toolbar;
+ new_globals->is_gtkw_save_file = GLOBALS->is_gtkw_save_file;
  new_globals->use_toolbutton_interface = GLOBALS->use_toolbutton_interface;
  new_globals->optimize_vcd = GLOBALS->optimize_vcd;
  strcpy2_into_new_context(new_globals, &new_globals->winname, &GLOBALS->winname); /* for page swapping */
 
  /* menu.c */
  new_globals->wave_script_args = GLOBALS->wave_script_args;
+#ifndef WAVE_USE_MLIST_T
  new_globals->item_factory_menu_c_1 = GLOBALS->item_factory_menu_c_1;
+#endif
  strcpy2_into_new_context(new_globals, &new_globals->filesel_writesave, &GLOBALS->filesel_writesave);
  new_globals->save_success_menu_c_1 = GLOBALS->save_success_menu_c_1; 
  new_globals->signal_popup_menu = GLOBALS->signal_popup_menu;
@@ -1756,9 +1904,6 @@ void reload_into_new_context(void)
 #endif
  new_globals->dual_ctx = GLOBALS->dual_ctx;
   
- new_globals->rpc_id = GLOBALS->rpc_id;
- new_globals->rpc_ctx = GLOBALS->rpc_ctx;
-
  /* Times struct */
  memcpy(&(new_globals->tims), &(GLOBALS->tims), sizeof(Times));
 
@@ -1915,8 +2060,8 @@ void reload_into_new_context(void)
  /* erase any old tabbed contexts if they exist... */
  dead_context_sweep();
 
- /* let any destructors finalize on GLOBALS dereferences... */
- gtkwave_main_iteration();
+ /* let any destructors finalize on GLOBALS dereferences... (commented out for now) */
+ /* gtkwave_main_iteration(); */
 
  /* Free the old context */
  free_outstanding();
@@ -1989,112 +2134,7 @@ void reload_into_new_context(void)
 		case LXT_FILE:
    		case VCD_FILE: 
 		case VCD_RECODER_FILE: 
-			GLOBALS->vcd_jmp_buf = calloc(1, sizeof(jmp_buf));
-			setjmp_globals =  calloc(1,sizeof(struct Global));      /* allocate yet another copy of viewer context */
-			memcpy(setjmp_globals, GLOBALS, sizeof(struct Global));	/* clone */
-			GLOBALS->alloc2_chain = NULL;				/* will merge this in after load if successful */
-			GLOBALS->outstanding = 0;				/* zero out count of chunks in this ctx */
-
-			if(!setjmp(*(GLOBALS->vcd_jmp_buf)))			/* loader exception handling */
-				{
-				switch(GLOBALS->loaded_file_type)		/* on fail, longjmp called in these loaders */
-					{			
-			   		case LXT_FILE: lxt_main(GLOBALS->loaded_file_name); break;
-			   		case VCD_FILE: vcd_main(GLOBALS->loaded_file_name); break;
-					case VCD_RECODER_FILE: vcd_recoder_main(GLOBALS->loaded_file_name); break;
-					default: break;
-					}
-				
-#ifdef _WAVE_HAVE_JUDY
-				{
-				Pvoid_t  PJArray = (Pvoid_t)setjmp_globals->alloc2_chain;
-				int rcValue;
-				Word_t Index;
-
-				Index = 0;
-				for (rcValue = Judy1First(PJArray, &Index, PJE0); rcValue != 0; rcValue = Judy1Next(PJArray, &Index, PJE0))
-					{
-				        Judy1Set ((Pvoid_t)&GLOBALS->alloc2_chain, Index, PJE0);
-					}
-
-				GLOBALS->outstanding += setjmp_globals->outstanding;
-				Judy1FreeArray(&PJArray, PJE0);
-				}
-#else
-				{
-				void **t, **t2;
-
-				t = (void **)setjmp_globals->alloc2_chain;
-				while(t)
-					{
-					t2 = (void **) *(t+1);
-					if(t2)
-						{
-						t = t2;
-						}
-						else
-						{
-						*(t+1) = GLOBALS->alloc2_chain;
-						if(GLOBALS->alloc2_chain)
-							{
-							t2 = (void **)GLOBALS->alloc2_chain;
-							*(t2+0) = t;
-							}
-						GLOBALS->alloc2_chain = setjmp_globals->alloc2_chain;
-						GLOBALS->outstanding += setjmp_globals->outstanding;
-						break;					
-						}
-					}
-				}
-#endif
-				free(GLOBALS->vcd_jmp_buf); GLOBALS->vcd_jmp_buf = NULL;
-				free(setjmp_globals); setjmp_globals = NULL;
-
-				load_was_success = 1;
-				}
-				else
-				{
-				free(GLOBALS->vcd_jmp_buf); GLOBALS->vcd_jmp_buf = NULL;
-				if(GLOBALS->vcd_handle_vcd_c_1)
-					{
-					if(GLOBALS->vcd_is_compressed_vcd_c_1)
-					        {
-					        pclose(GLOBALS->vcd_handle_vcd_c_1);
-					        GLOBALS->vcd_handle_vcd_c_1 = NULL;
-					        }
-					        else
-					        {
-					        fclose(GLOBALS->vcd_handle_vcd_c_1);
-					        GLOBALS->vcd_handle_vcd_c_1 = NULL;
-					        }
-					}
-				if(GLOBALS->vcd_handle_vcd_recoder_c_2)
-					{
-					if(GLOBALS->vcd_is_compressed_vcd_recoder_c_2)
-	        				{
-	        				pclose(GLOBALS->vcd_handle_vcd_recoder_c_2);
-	        				GLOBALS->vcd_handle_vcd_recoder_c_2 = NULL;
-	        				}    
-	        				else
-	        				{
-	        				fclose(GLOBALS->vcd_handle_vcd_recoder_c_2);
-	        				GLOBALS->vcd_handle_vcd_recoder_c_2 = NULL;
-	        				}
-					}
-
-
-				if(GLOBALS->vlist_handle) { fclose(GLOBALS->vlist_handle); GLOBALS->vlist_handle = NULL; }
-				if(GLOBALS->mm_lxt_mmap_addr)
-					{                        
-					munmap(GLOBALS->mm_lxt_mmap_addr, GLOBALS->mm_lxt_mmap_len); 
-					GLOBALS->mm_lxt_mmap_addr = NULL;
-					}                        
-				free_outstanding(); /* free anything allocated in loader ctx */
-
-				memcpy(GLOBALS, setjmp_globals, sizeof(struct Global)); /* copy over old ctx */
-				free(setjmp_globals);					/* remove cached old ctx */
-				/* now try again, jump through recovery sequence below */
-				}
+			load_was_success = handle_setjmp();
 			break;
 		default:
 			break;
@@ -2199,7 +2239,7 @@ void reload_into_new_context(void)
  #endif
 
  /* Reload state from file */
- read_save_helper(reload_tmpfilename); 
+ read_save_helper(reload_tmpfilename, NULL, NULL, NULL, NULL); 
 
  /* again doing this here (read_save_helper does it) seems to be necessary in order to keep display in sync */
  GLOBALS->signalwindow_width_dirty=1;
@@ -2340,6 +2380,7 @@ void reload_into_new_context(void)
 	}
 
  /* restore these in case we decide to write out the rc file later as a user option */
+ GLOBALS->ignore_savefile_pane_pos = cached_ignore_savefile_pane_pos;
  GLOBALS->ignore_savefile_pos = cached_ignore_savefile_pos;
  GLOBALS->ignore_savefile_size = cached_ignore_savefile_size;
  GLOBALS->splash_disable = cached_splash_disable;
@@ -2352,7 +2393,7 @@ void reload_into_new_context(void)
    if((GLOBALS->dnd_sigview) && ((treeview_vadj_value != 0.0) || (treeview_hadj_value != 0.0)))
 	{
 	   struct Global *G2 = GLOBALS;
-	   while (gtk_events_pending()) gtk_main_iteration();
+	   gtk_events_pending_gtk_main_iteration();
 
 	   if((G2 == GLOBALS)&&(GLOBALS->dnd_sigview))
 		{
@@ -2389,6 +2430,27 @@ void reload_into_new_context(void)
 }
 
 
+void reload_into_new_context(void)
+{
+static int reloading = 0;
+
+if(!reloading)
+	{
+#ifdef MAC_INTEGRATION   
+	osx_menu_sensitivity(FALSE);
+#endif   
+	reload_into_new_context_2();
+	reloading = 0;
+#ifdef MAC_INTEGRATION   
+	if(GLOBALS->loaded_file_type != MISSING_FILE)
+		{
+		osx_menu_sensitivity(TRUE);
+		}
+#endif   
+	}
+}
+
+
 /*
  * for notebook page closing
  */
@@ -2514,6 +2576,11 @@ static gint context_swapper(GtkWindow *w, GdkEvent *event, void *data)
 {
 GdkEventType type;
 
+if(ignore_context_swap()) /* block context swap if explicitly directed (e.g., during loading) */
+	{
+	return(FALSE);
+	}
+
 type = event->type;
 
 /* printf("Window: %08x GtkEvent: %08x gpointer: %08x, type: %d\n", w, event, data, type); */
@@ -2569,6 +2636,10 @@ switch(type)
 							GLOBALS->zoom_dyn = g_old->zoom_dyn;
 							GLOBALS->zoom_dyne = g_old->zoom_dyne;
 
+							GLOBALS->ignore_savefile_pane_pos = g_old->ignore_savefile_pane_pos;
+							GLOBALS->ignore_savefile_pos = g_old->ignore_savefile_pos;
+							GLOBALS->ignore_savefile_size = g_old->ignore_savefile_size;
+
 							gtk_notebook_set_current_page(GTK_NOTEBOOK(GLOBALS->notebook), GLOBALS->this_context_page);
 							}
 
