@@ -29,6 +29,7 @@
 #include "fgetdynamic.h"
 #include "fonts.h"
 #include "fstapi.h"
+#include "gconf.h"
 #include "ghw.h"
 #include "globals.h"
 #include "gnu_regex.h"
@@ -45,6 +46,7 @@
 #include "ttranslate.h"
 #include "rc.h"
 #include "regex_wave.h"
+#include "savefile.h"
 #include "strace.h"
 #include "symbol.h"
 #include "tcl_helper.h"
@@ -224,7 +226,7 @@ char disable_tooltips; /* from debug.c 80 */
 GtkWidget *window_entry_c_1; /* from entry.c 81 */
 GtkWidget *entry_entry_c_1; /* from entry.c 82 */
 char *entrybox_text; /* from entry.c 83 */
-void (*cleanup_entry_c_1)(); /* from entry.c 84 */
+void (*cleanup_entry_c_1)(void); /* from entry.c 84 */
 
 
 /* extload.c */
@@ -260,8 +262,8 @@ GPatternSpec *pPatternSpec;
 GtkWidget *fs_file_c_1; /* from file.c 87 */
 char **fileselbox_text; /* from file.c 88 */
 char filesel_ok; /* from file.c 89 */
-void (*cleanup_file_c_2)(); /* from file.c 90 */
-void (*bad_cleanup_file_c_1)(); /* from file.c 91 */
+void (*cleanup_file_c_2)(void); /* from file.c 90 */
+void (*bad_cleanup_file_c_1)(void); /* from file.c 91 */
 
 
 /* 
@@ -359,13 +361,13 @@ GtkWidget *window_hiersearch_c_3; /* from hiersearch.c 121 */
 GtkWidget *entry_main_hiersearch_c_1; /* from hiersearch.c 122 */
 GtkWidget *clist_hiersearch_c_1; /* from hiersearch.c 123 */
 char bundle_direction_hiersearch_c_1; /* from hiersearch.c 124 */
-void (*cleanup_hiersearch_c_3)(); /* from hiersearch.c 125 */
+void (*cleanup_hiersearch_c_3)(void); /* from hiersearch.c 125 */
 int num_rows_hiersearch_c_1; /* from hiersearch.c 126 */
 int selected_rows_hiersearch_c_1; /* from hiersearch.c 127 */
 GtkWidget *window1_hiersearch_c_1; /* from hiersearch.c 128 */
 GtkWidget *entry_hiersearch_c_2; /* from hiersearch.c 129 */
 char *entrybox_text_local_hiersearch_c_1; /* from hiersearch.c 130 */
-void (*cleanup_e_hiersearch_c_1)(); /* from hiersearch.c 131 */
+void (*cleanup_e_hiersearch_c_1)(void); /* from hiersearch.c 131 */
 struct tree *h_selectedtree_hiersearch_c_1; /* from hiersearch.c 132 */
 struct tree *current_tree_hiersearch_c_1; /* from hiersearch.c 133 */
 struct treechain *treechain_hiersearch_c_1; /* from hiersearch.c 134 */
@@ -464,6 +466,8 @@ unsigned int *lastchange;
 /*
  * main.c
  */
+char is_gtkw_save_file;
+gboolean dumpfile_is_modified;
 GtkWidget *missing_file_toolbar;
 char *argvlist;
 #ifdef HAVE_LIBTCL
@@ -498,12 +502,14 @@ struct gtkwave_dual_ipc_t *dual_ctx; /* from main.c 207 */
 int dual_id; /* from main.c 208 */
 unsigned int dual_attach_id_main_c_1; /* from main.c 209 */
 int dual_race_lock; /* from main.c 210 */
-struct gtkwave_rpc_ipc_t *rpc_ctx; /* from main.c */
-unsigned int rpc_id; /* from main.c */
 GtkWidget *mainwindow; /* from main.c 211 */
 GtkWidget *signalwindow; /* from main.c 212 */
 GtkWidget *wavewindow; /* from main.c 213 */
 GtkWidget *toppanedwindow; /* from main.c 214 */
+GtkWidget *panedwindow;
+gint toppanedwindow_size_cache;
+gint panedwindow_size_cache;
+gint vpanedwindow_size_cache;
 GtkWidget *sstpane; /* from main.c 215 */
 GtkWidget *expanderwindow; /* from main.c 216 */
 char disable_window_manager; /* from main.c 217 */
@@ -544,7 +550,7 @@ char use_toolbutton_interface; /* from main.c */
  */
 GtkWidget *window_markerbox_c_4; /* from markerbox.c 248 */
 GtkWidget *entries_markerbox_c_1[26]; /* from markerbox.c 249 */
-void (*cleanup_markerbox_c_4)(); /* from markerbox.c 250 */
+void (*cleanup_markerbox_c_4)(void); /* from markerbox.c 250 */
 int dirty_markerbox_c_1; /* from markerbox.c 251 */
 TimeType shadow_markers_markerbox_c_1[26]; /* from markerbox.c 252 */
 char *marker_names[26]; /* from markerbox.c */
@@ -555,10 +561,14 @@ char *shadow_marker_names[26]; /* from markerbox.c */
  */
 char *cutcopylist; /* from menu.c */
 char enable_fast_exit; /* from menu.c 253 */
+char quiet_checkmenu;
 struct wave_script_args *wave_script_args; /* from tcl_helper.c */
+char ignore_savefile_pane_pos;
 char ignore_savefile_pos; /* from menu.c 255 */
 char ignore_savefile_size; /* from menu.c 256 */
+#ifndef WAVE_USE_MLIST_T
 GtkItemFactory *item_factory_menu_c_1; /* from menu.c 258 */
+#endif
 char *regexp_string_menu_c_1; /* from menu.c 259 */
 struct TraceEnt *trace_to_alias_menu_c_1; /* from menu.c 260 */
 struct TraceEnt *showchangeall_menu_c_1; /* from menu.c 261 */
@@ -711,10 +721,17 @@ char *filesel_print_ps_renderopt_c_1; /* from renderopt.c 343 */
 char *filesel_print_mif_renderopt_c_1; /* from renderopt.c 344 */
 char target_mutex_renderopt_c_1[3]; /* from renderopt.c 346 */
 char page_mutex_renderopt_c_1[5]; /* from renderopt.c 348 */
-char render_mutex_renderopt_c_1[2]; /* from renderopt.c 350 */
+char render_mutex_renderopt_c_1[3]; /* from renderopt.c 350 */
 int page_size_type_renderopt_c_1; /* from renderopt.c 351 */
 
 
+/*
+ * savefile.c
+ */
+char *sfn;
+char *lcname;
+
+
 /*
  * search.c
  */
@@ -722,7 +739,7 @@ GtkWidget *menuitem_search[5]; /* from search.c */
 GtkWidget *window1_search_c_2; /* from search.c 359 */
 GtkWidget *entry_a_search_c_1; /* from search.c 360 */
 char *entrybox_text_local_search_c_2; /* from search.c 361 */
-void (*cleanup_e_search_c_2)(); /* from search.c 362 */
+void (*cleanup_e_search_c_2)(void); /* from search.c 362 */
 SearchProgressData *pdata; /* from search.c 363 */
 int is_active_search_c_4; /* from search.c 364 */
 char is_insert_running_search_c_1; /* from search.c 365 */
@@ -736,7 +753,7 @@ GtkWidget *entry_search_c_3; /* from search.c 374 */
 GtkWidget *clist_search_c_3; /* from search.c 375 */
 char *searchbox_text_search_c_1; /* from search.c 377 */
 char bundle_direction_search_c_2; /* from search.c 378 */
-void (*cleanup_search_c_5)(); /* from search.c 379 */
+void (*cleanup_search_c_5)(void); /* from search.c 379 */
 int num_rows_search_c_2; /* from search.c 380 */
 int selected_rows_search_c_2; /* from search.c 381 */
 
@@ -755,7 +772,7 @@ GtkWidget *toggle2_showchange_c_1; /* from showchange.c 389 */
 GtkWidget *toggle3_showchange_c_1; /* from showchange.c 390 */
 GtkWidget *toggle4_showchange_c_1; /* from showchange.c 391 */
 GtkWidget *window_showchange_c_8; /* from showchange.c 392 */
-void (*cleanup_showchange_c_6)(); /* from showchange.c 393 */
+void (*cleanup_showchange_c_6)(void); /* from showchange.c 393 */
 struct TraceEnt *tcache_showchange_c_1; /* from showchange.c 394 */
 unsigned int flags_showchange_c_1; /* from showchange.c 395 */
 
@@ -766,6 +783,9 @@ unsigned int flags_showchange_c_1; /* from showchange.c 395 */
 GtkWidget *signalarea; /* from signalwindow.c 396 */
 struct font_engine_font_t *signalfont; /* from signalwindow.c 397 */
 GdkDrawable *signalpixmap; /* from signalwindow.c 398 */
+#ifdef WAVE_ALLOW_QUARTZ_FLUSH_WORKAROUND
+char force_hide_show;
+#endif
 int max_signal_name_pixel_width; /* from signalwindow.c 399 */
 int signal_pixmap_width; /* from signalwindow.c 400 */
 int signal_fill_width; /* from signalwindow.c 401 */
@@ -804,6 +824,8 @@ void (*cleanup)(GtkWidget *, void *); /* from simplereq.c 414 */
 /*
  * splash.c
  */
+char splash_is_loading;
+char splash_fix_win_title;
 char splash_disable; /* from splash.c 415 */
 GdkDrawable *wave_splash_pixmap; /* from splash.c 417 */
 GdkDrawable *wave_splash_mask; /* from splash.c 418 */
@@ -930,19 +952,19 @@ int comp_name_longest;
 GtkWidget *window1_treesearch_gtk1_c;  /* manual adds by ajb... */
 GtkWidget *entry_a_treesearch_gtk1_c; 
 char *entrybox_text_local_treesearch_gtk1_c; 
-void (*cleanup_e_treesearch_gtk1_c)();
+void (*cleanup_e_treesearch_gtk1_c)(void);
 struct tree *selectedtree_treesearch_gtk1_c; 
 int is_active_treesearch_gtk1_c; 
 GtkWidget *window_treesearch_gtk1_c; 
 GtkWidget *tree_treesearch_gtk1_c;
 char bundle_direction_treesearch_gtk1_c; 
-void (*cleanup_treesearch_gtk1_c)(); /* ...end of manual adds */
+void (*cleanup_treesearch_gtk1_c)(void); /* ...end of manual adds */
 
 
 /*
  * treesearch_gtk2.c
  */
-#ifdef WAVE_GDK_QUARTZ
+#ifdef MAC_INTEGRATION
 char *dnd_helper_quartz;
 #endif
 struct string_chain_t *treeopen_chain_head; /* from bitvec.c */
@@ -961,7 +983,7 @@ char autoname_bundles; /* from treesearch_gtk2.c 483 */
 GtkWidget *window1_treesearch_gtk2_c_3; /* from treesearch_gtk2.c 484 */
 GtkWidget *entry_a_treesearch_gtk2_c_2; /* from treesearch_gtk2.c 485 */
 char *entrybox_text_local_treesearch_gtk2_c_3; /* from treesearch_gtk2.c 486 */
-void (*cleanup_e_treesearch_gtk2_c_3)(); /* from treesearch_gtk2.c 487 */
+void (*cleanup_e_treesearch_gtk2_c_3)(void); /* from treesearch_gtk2.c 487 */
 struct tree *sig_root_treesearch_gtk2_c_1; /* from treesearch_gtk2.c 488 */
 char *filter_str_treesearch_gtk2_c_1; /* from treesearch_gtk2.c 489 */
 #if defined(WAVE_USE_GTK2) 
@@ -974,7 +996,7 @@ struct autocoalesce_free_list *afl_treesearch_gtk2_c_1; /* from treesearch_gtk2.
 GtkWidget *window_treesearch_gtk2_c_12; /* from treesearch_gtk2.c 495 */
 GtkWidget *tree_treesearch_gtk2_c_1; /* from treesearch_gtk2.c 496 */
 char bundle_direction_treesearch_gtk2_c_3; /* from treesearch_gtk2.c 497 */
-void (*cleanup_treesearch_gtk2_c_8)(); /* from treesearch_gtk2.c 498 */
+void (*cleanup_treesearch_gtk2_c_8)(void); /* from treesearch_gtk2.c 498 */
 int pre_import_treesearch_gtk2_c_1; /* from treesearch_gtk2.c 499 */
 Traces tcache_treesearch_gtk2_c_2; /* from treesearch_gtk2.c 500 */
 unsigned char dnd_tgt_on_signalarea_treesearch_gtk2_c_1; /* from treesearch_gtk2.c 501 */
