@@ -233,11 +233,12 @@ static void enter_callback_e(GtkWidget *widget, GtkWidget *nothing)
   G_CONST_RETURN gchar *entry_text;
   int len;
   entry_text = gtk_entry_get_text(GTK_ENTRY(GLOBALS->entry_hiersearch_c_2));
+  entry_text = entry_text ? entry_text : "";
   DEBUG(printf("Entry contents: %s\n", entry_text));
   if(!(len=strlen(entry_text))) GLOBALS->entrybox_text_local_hiersearch_c_1=NULL;
 	else strcpy((GLOBALS->entrybox_text_local_hiersearch_c_1=(char *)malloc_2(len+1)),entry_text);
 
-  gtk_grab_remove(GLOBALS->window1_hiersearch_c_1);
+  wave_gtk_grab_remove(GLOBALS->window1_hiersearch_c_1);
   gtk_widget_destroy(GLOBALS->window1_hiersearch_c_1);
   GLOBALS->window1_hiersearch_c_1 = NULL;
 
@@ -248,7 +249,7 @@ static void destroy_callback_e(GtkWidget *widget, GtkWidget *nothing)
 {
   DEBUG(printf("Entry Cancel\n"));
   GLOBALS->entrybox_text_local_hiersearch_c_1=NULL;
-  gtk_grab_remove(GLOBALS->window1_hiersearch_c_1);
+  wave_gtk_grab_remove(GLOBALS->window1_hiersearch_c_1);
   gtk_widget_destroy(GLOBALS->window1_hiersearch_c_1);
   GLOBALS->window1_hiersearch_c_1 = NULL;
 }
@@ -299,7 +300,7 @@ static void entrybox_local(char *title, int width, char *default_text, int maxch
     gtk_container_add (GTK_CONTAINER (hbox), button2);
 
     gtk_widget_show(GLOBALS->window1_hiersearch_c_1);
-    gtk_grab_add(GLOBALS->window1_hiersearch_c_1);
+    wave_gtk_grab_add(GLOBALS->window1_hiersearch_c_1);
 }
 
 /***************************************************************************/
