@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell 1999-2011.
+ * Copyright (c) Tony Bybell 1999-2012.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -29,6 +29,7 @@
 #include <sys/wait.h>
 #include <sys/time.h>
 #include <sys/types.h>
+#include <sys/stat.h>
 #endif
 
 #if !defined _MSC_VER && defined WAVE_USE_GTK2
@@ -74,12 +75,71 @@
 #include <tk.h>
 #endif
 
-#include "wave_rpc.h"
+#ifdef MAC_INTEGRATION
+#include <gtkosxapplication.h>
+#endif
 
-static int suffix_check(const char *s, const char *sfx)
+char *gtkwave_argv0_cached = NULL;
+
+static char *extract_dumpname_from_save_file(char *lcname, gboolean *modified)
 {
-int sfxlen = strlen(sfx);
-return((strlen(s)>=sfxlen)&&(!strcasecmp(s+strlen(s)-sfxlen,sfx)));
+char *dfn = NULL;
+char *sfn = NULL;
+char *rp = NULL;
+FILE *f;
+off_t dumpsiz = -1;
+time_t dumptim = -1;
+
+if ((suffix_check(lcname, ".sav")) || (suffix_check(lcname, ".gtkw")))
+	{
+	read_save_helper(lcname, &dfn, &sfn, &dumpsiz, &dumptim);
+
+#if defined __USE_BSD || defined __USE_XOPEN_EXTENDED || defined __CYGWIN__ || defined HAVE_REALPATH
+	if(sfn && dfn)
+		{
+		char *can = realpath(lcname, NULL);
+		char *fdf = find_dumpfile(sfn, dfn, can);
+
+		free(can);
+		f = fopen(fdf, "rb");
+		if(f)
+			{
+			rp = fdf;
+			fclose(f);
+			goto bot;
+			}
+		}
+#endif
+
+	if(dfn)
+		{
+		f = fopen(dfn, "rb");
+		if(f)
+			{
+			fclose(f);
+			rp = strdup_2(dfn);
+			goto bot;
+			}
+		}
+	}
+
+bot:
+if(dfn) free_2(dfn);
+if(sfn) free_2(sfn);
+
+if(modified) *modified = 0;
+#if !defined __MINGW32__ && !defined _MSC_VER
+if(modified && rp && (dumpsiz != -1) && (dumptim != -1))
+	{
+	struct stat sbuf;
+        if(!stat(rp, &sbuf))
+		{
+		*modified = (dumpsiz != sbuf.st_size) || (dumptim != sbuf.st_mtime);
+                }
+	}
+#endif
+
+return(rp);
 }
 
 
@@ -126,7 +186,7 @@ GLOBALS->keypress_handler_id = g_old->keypress_handler_id;
 
 if(GLOBALS->second_page_created)
 	{
-	gtk_window_set_title(GTK_WINDOW(GLOBALS->mainwindow), GLOBALS->winname);
+	wave_gtk_window_set_title(GTK_WINDOW(GLOBALS->mainwindow), GLOBALS->winname, GLOBALS->dumpfile_is_modified ? WAVE_SET_TITLE_MODIFIED: WAVE_SET_TITLE_NONE, 0);
 
 	MaxSignalLength();
 	signalarea_configure_event(GLOBALS->signalarea, NULL);
@@ -250,10 +310,18 @@ static void print_help(char *nam)
 
 #if !defined _MSC_VER && !defined __MINGW32__
 #define OUTPUT_GETOPT "  -O, --output=FILE          specify filename for stdout/stderr redirect\n"
-#define RPC_GETOPT "  -1, --rpcid=RPCID          specify RPCID of gtkwave_server to connect to\n"
+#define CHDIR_GETOPT "  -2, --chdir=DIR            specify new current working directory\n"
 #else
 #define OUTPUT_GETOPT
+#define CHDIR_GETOPT
+#endif
+
+#ifdef WAVE_HAVE_GCONF
+#define RPC_GETOPT  "  -1, --rpcid=RPCID          specify RPCID of GConf session\n"
+#define RPC_GETOPT3 "  -3, --restore              restore previous RPCID numbered session\n"
+#else
 #define RPC_GETOPT
+#define RPC_GETOPT3
 #endif
 
 #if defined(WAVE_USE_GTK2)
@@ -284,6 +352,8 @@ WAVE_GETOPT_CPUS
 REPSCRIPT_GETOPT
 XID_GETOPT
 RPC_GETOPT
+CHDIR_GETOPT
+RPC_GETOPT3
 INTR_GETOPT
 "  -C, --comphier             use compressed hierarchy names (slower)\n"
 "  -g, --giga                 use gigabyte mempacking when recoding (slower)\n"
@@ -377,6 +447,7 @@ static char *winprefix="GTKWave - ";
 static char *winstd="GTKWave (stdio) ";
 static char *vcd_autosave_name="vcd_autosave.sav";
 char *output_name = NULL;
+char *chdir_cache = NULL;
 
 int i;
 int c;
@@ -416,6 +487,9 @@ int tcl_interpreter_needs_making = 0;
 
 int splash_disable_rc_override = 0;
 int mainwindow_already_built;
+#ifdef MAC_INTEGRATION
+GdkPixbuf *dock_pb;
+#endif
 
 WAVE_LOCALE_FIX
 
@@ -454,7 +528,9 @@ if(!GLOBALS)
 #if defined(HAVE_LIBTCL)
 	GLOBALS->interp = old_g->interp;
 #endif
+#ifndef WAVE_USE_MLIST_T
 	GLOBALS->item_factory_menu_c_1 = old_g->item_factory_menu_c_1;
+#endif
 	GLOBALS->vcd_jmp_buf = old_g->vcd_jmp_buf;
 
 	/* currenttime.c */
@@ -479,6 +555,7 @@ if(!GLOBALS)
 	
 	/* rc.c */
 	GLOBALS->possibly_use_rc_defaults = old_g->possibly_use_rc_defaults;
+	GLOBALS->ignore_savefile_pane_pos = old_g->ignore_savefile_pane_pos;
 	GLOBALS->ignore_savefile_pos = old_g->ignore_savefile_pos;
 	GLOBALS->ignore_savefile_size = old_g->ignore_savefile_size;
 	
@@ -590,6 +667,8 @@ if(!GLOBALS)
 	GLOBALS->use_scrollwheel_as_y = old_g->use_scrollwheel_as_y;
 	GLOBALS->enable_slider_zoom = old_g->enable_slider_zoom;
 
+	GLOBALS->missing_file_toolbar = old_g->missing_file_toolbar;
+
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->fontname_logfile, &old_g->fontname_logfile);
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->fontname_signals, &old_g->fontname_signals); 
 	strcpy2_into_new_context(GLOBALS, &GLOBALS->fontname_waves, &old_g->fontname_waves);
@@ -609,6 +688,7 @@ if(!mainwindow_already_built)
 	if(!gtk_init_check(&argc, &argv))
 		{
 #if defined(__APPLE__)
+#ifndef MAC_INTEGRATION
 		if(!getenv("DISPLAY"))
 			{
 			fprintf(stderr, "DISPLAY environment variable is not set.  Have you ensured\n");
@@ -621,6 +701,7 @@ if(!mainwindow_already_built)
 				goto do_primary_inits;
 				}
 			}
+#endif
 #endif
 		fprintf(stderr, "Could not initialize GTK!  Is DISPLAY env var/xhost set?\n\n");
 		print_help(argv[0]);
@@ -631,6 +712,13 @@ if(!mainwindow_already_built)
 do_primary_inits:
 #endif
 
+if(!mainwindow_already_built)
+	{
+	wave_gconf_init(argc, argv);
+	}
+
+if(!gtkwave_argv0_cached) gtkwave_argv0_cached = argv[0]; /* for new window option */
+
 init_filetrans_data(); /* for file translation splay trees */
 init_proctrans_data(); /* for proc translation structs */
 init_ttrans_data();    /* for transaction proc translation structs */
@@ -686,11 +774,13 @@ while (1)
                 {"repperiod", 1, 0, 'P'},
 		{"output", 1, 0, 'O' },
                 {"slider-zoom", 0, 0, 'z'},
-		{"rpc", 1, 0, '1' },
+		{"rpcid", 1, 0, '1' },
+		{"chdir", 1, 0, '2'},
+		{"restore", 0, 0, '3'},
                 {0, 0, 0, 0}
                 };
 
-        c = getopt_long (argc, argv, "zf:Fon:a:Ar:dl:s:e:c:t:NS:vVhxX:MD:IgCLR:P:O:WT:1:", long_options, 
+        c = getopt_long (argc, argv, "zf:Fon:a:Ar:dl:s:e:c:t:NS:vVhxX:MD:IgCLR:P:O:WT:1:2:3", long_options, 
 &option_index);
 
         if (c == -1) break;     /* no more args */
@@ -802,7 +892,49 @@ while (1)
 #endif
 
 		case '1':
-			sscanf(optarg, "%x", &GLOBALS->rpc_id);
+			sscanf(optarg, "%d", &wave_rpc_id);
+			if(wave_rpc_id < 0) wave_rpc_id = 0;
+			break;
+
+		case '2':
+#ifndef _MSC_VER  
+			{
+			char *chdir_env = getenv("GTKWAVE_CHDIR"); 
+
+			if(chdir_cache)
+				{
+				free_2(chdir_cache);
+				}
+
+			chdir_cache = strdup_2(chdir_env ? chdir_env : optarg);
+			if(chdir(chdir_cache) < 0)
+				{
+				fprintf(stderr, "GTKWAVE | Could not chdir '%s', exiting.\n", chdir_cache);
+				perror("Why");
+				exit(255);
+				}
+			}
+#endif
+			break;
+
+		case '3':
+			{
+			is_vcd = 0;
+			wave_gconf_restore(&GLOBALS->loaded_file_name, &wname, &override_rc, &chdir_cache);
+                        if(chdir_cache)
+                                {
+                                if(chdir(chdir_cache) < 0)
+                                        {
+                                        fprintf(stderr, "GTKWAVE | Could not chdir '%s', exiting.\n", chdir_cache);
+                                        perror("Why");
+                                        exit(255);
+                                        }
+                                }
+			fprintf(stderr, "GTKWAVE | restore cwd  '%s'\n", chdir_cache ? chdir_cache : "(none)");
+			fprintf(stderr, "GTKWAVE | restore dump '%s'\n", GLOBALS->loaded_file_name ? GLOBALS->loaded_file_name : "(none)");
+			fprintf(stderr, "GTKWAVE | restore save '%s'\n", wname ? wname : "(none)");
+			fprintf(stderr, "GTKWAVE | restore rc   '%s'\n", override_rc ? override_rc : "(none)");
+			}
 			break;
 
 		case 'M':
@@ -1025,6 +1157,34 @@ if(is_wish && is_vcd)
 	exit(255);
 	}
 
+/* attempt to load a dump+save file if only a savefile is specified at the command line */
+if((GLOBALS->loaded_file_name) && (!wname) &&
+	(suffix_check(GLOBALS->loaded_file_name, ".gtkw") || suffix_check(GLOBALS->loaded_file_name, ".sav")))
+	{
+	char *extracted_name = extract_dumpname_from_save_file(GLOBALS->loaded_file_name, &GLOBALS->dumpfile_is_modified);
+	if(extracted_name)
+		{
+		if(mainwindow_already_built)
+			{
+			deal_with_rpc_open_2(GLOBALS->loaded_file_name, NULL, TRUE);
+			GLOBALS->loaded_file_name = extracted_name;
+			/* wname is still NULL */
+			}
+			else
+			{
+			wname = GLOBALS->loaded_file_name;
+			GLOBALS->loaded_file_name = extracted_name;
+			}
+		}
+	}
+else /* same as above but with --save specified */
+if((!GLOBALS->loaded_file_name) && wname)
+	{
+	GLOBALS->loaded_file_name = extract_dumpname_from_save_file(wname, &GLOBALS->dumpfile_is_modified);
+	/* still can be NULL if file not found... */
+	}
+
+
 read_rc_file(override_rc);
 GLOBALS->splash_disable |= splash_disable_rc_override;
 
@@ -1136,7 +1296,7 @@ if(is_missing_file)
 	}
 else
 #ifdef EXTLOAD_SUFFIX
-if(suffix_check(GLOBALS->loaded_file_name, EXTLOAD_SUFFIX))
+if(suffix_check(GLOBALS->loaded_file_name, "."EXTLOAD_SUFFIX))
 	{
 	TimeType extload_max;
 
@@ -1350,6 +1510,8 @@ if((wname)||(vcd_save_handle_cached)||(is_smartsave))
 	int wave_is_compressed;
         char *str = NULL;
 
+	GLOBALS->is_gtkw_save_file = (!wname) || suffix_check(wname, ".gtkw");
+
 	if(vcd_save_handle_cached)
 		{
 		wname=vcd_autosave_name;
@@ -1384,9 +1546,9 @@ if((wname)||(vcd_save_handle_cached)||(is_smartsave))
 				} while(pnt2-- != pnt);
 			}	
 
-		wname = malloc_2(strlen(pnt) + 5);
+		wname = malloc_2(strlen(pnt) + 6);
 		strcpy(wname, pnt);
-		strcat(wname, ".sav");
+		strcat(wname, ".gtkw");
 		}
 
 	if(((strlen(wname)>2)&&(!strcasecmp(wname+strlen(wname)-3,".gz")))||
@@ -1411,7 +1573,7 @@ if((wname)||(vcd_save_handle_cached)||(is_smartsave))
 
 	if(!wave)
 	        {
-	        fprintf(stderr, "** WARNING: Error opening .sav file '%s', skipping.\n",wname);
+	        fprintf(stderr, "** WARNING: Error opening save file '%s', skipping.\n",wname);
 	        }	
 	        else
 	        {
@@ -1454,12 +1616,13 @@ if((wname)||(vcd_save_handle_cached)||(is_smartsave))
 
 			if(!wave)
 			        {
-			        fprintf(stderr, "** WARNING: Error opening .sav file '%s', skipping.\n",wname);
+			        fprintf(stderr, "** WARNING: Error opening save file '%s', skipping.\n",wname);
 				EnsureGroupsMatch();
 				goto savefile_bail;
 			        }	
 			}
 
+		read_save_helper_relative_init(wname);
 		GLOBALS->default_flags=TR_RJUSTIFY;
 		GLOBALS->shift_timebase_default_for_add=LLDescriptor(0);
 		GLOBALS->strace_current_window = 0; /* in case there are shadow traces */
@@ -1522,7 +1685,7 @@ if(!GLOBALS->socket_xid)
 #endif
         {
 	GLOBALS->mainwindow = gtk_window_new(GLOBALS->disable_window_manager ? GTK_WINDOW_POPUP : GTK_WINDOW_TOPLEVEL);
-	gtk_window_set_title(GTK_WINDOW(GLOBALS->mainwindow), GLOBALS->winname);
+	wave_gtk_window_set_title(GTK_WINDOW(GLOBALS->mainwindow), GLOBALS->winname, GLOBALS->dumpfile_is_modified ? WAVE_SET_TITLE_MODIFIED: WAVE_SET_TITLE_NONE, 0);
 
 	if((GLOBALS->initial_window_width>0)&&(GLOBALS->initial_window_height>0))
 		{
@@ -1548,7 +1711,9 @@ if(!GLOBALS->socket_xid)
 #endif
 }
 
-
+#ifdef MAC_INTEGRATION
+dock_pb =
+#endif
 make_pixmaps(GLOBALS->mainwindow);
 
 #ifdef WAVE_USE_GTK2
@@ -1568,8 +1733,30 @@ if(GLOBALS->use_toolbutton_interface)
 	
 		if(!GLOBALS->disable_menus)
 			{
+#ifdef WAVE_USE_MLIST_T
+			menubar = alt_menu_top(GLOBALS->mainwindow);
+#else
 			get_main_menu(GLOBALS->mainwindow, &menubar);
+#endif
 			gtk_widget_show(menubar);
+
+#ifdef MAC_INTEGRATION
+{
+GtkOSXApplication *theApp = theApp = g_object_new(GTK_TYPE_OSX_APPLICATION, NULL);
+gtk_widget_hide(menubar);
+gtk_osxapplication_set_menu_bar(theApp, GTK_MENU_SHELL(menubar));
+gtk_osxapplication_set_use_quartz_accelerators(theApp, TRUE);
+gtk_osxapplication_ready(theApp);
+gtk_osxapplication_set_dock_icon_pixbuf(theApp, dock_pb);
+if(GLOBALS->loaded_file_type == MISSING_FILE)
+	{
+	gtk_osxapplication_attention_request(theApp, INFO_REQUEST);
+	}
+
+g_signal_connect(theApp, "NSApplicationOpenFile", G_CALLBACK(deal_with_finder_open), NULL);
+g_signal_connect(theApp, "NSApplicationBlockTermination", G_CALLBACK(deal_with_termination), NULL);
+}
+#endif
 	
 			if(GLOBALS->force_toolbars)
 				{
@@ -1791,9 +1978,31 @@ if(GLOBALS->use_toolbutton_interface)
 	
 		if(!GLOBALS->disable_menus)
 			{
+#ifdef WAVE_USE_MLIST_T
+			menubar = alt_menu_top(GLOBALS->mainwindow);
+#else
 			get_main_menu(GLOBALS->mainwindow, &menubar);
+#endif
 			gtk_widget_show(menubar);
-	
+
+#ifdef MAC_INTEGRATION
+{
+GtkOSXApplication *theApp = theApp = g_object_new(GTK_TYPE_OSX_APPLICATION, NULL);
+gtk_widget_hide(menubar);
+gtk_osxapplication_set_menu_bar(theApp, GTK_MENU_SHELL(menubar));
+gtk_osxapplication_set_use_quartz_accelerators(theApp, TRUE);
+gtk_osxapplication_ready(theApp);
+gtk_osxapplication_set_dock_icon_pixbuf(theApp, dock_pb);
+if(GLOBALS->loaded_file_type == MISSING_FILE)
+	{
+	gtk_osxapplication_attention_request(theApp, INFO_REQUEST);
+	}
+
+g_signal_connect(theApp, "NSApplicationOpenFile", G_CALLBACK(deal_with_finder_open), NULL);
+g_signal_connect(theApp, "NSApplicationBlockTermination", G_CALLBACK(deal_with_termination), NULL);
+}
+#endif
+
 			if(GLOBALS->force_toolbars)
 				{
 				toolhandle=gtk_handle_box_new();
@@ -1979,12 +2188,22 @@ if((!GLOBALS->hide_sst)&&(GLOBALS->loaded_file_type != MISSING_FILE))
 	GLOBALS->sstpane = treeboxframe("SST", GTK_SIGNAL_FUNC(mkmenu_treesearch_cleanup));
 	GLOBALS->expanderwindow = gtk_expander_new_with_mnemonic("_SST");
 	gtk_expander_set_expanded(GTK_EXPANDER(GLOBALS->expanderwindow), (GLOBALS->sst_expanded==TRUE));
+	if(GLOBALS->toppanedwindow_size_cache)
+		{
+		gtk_paned_set_position(GTK_PANED(GLOBALS->toppanedwindow), GLOBALS->toppanedwindow_size_cache);
+		GLOBALS->toppanedwindow_size_cache = 0;
+		}
 	gtk_container_add(GTK_CONTAINER(GLOBALS->expanderwindow), GLOBALS->sstpane);
 	gtk_widget_show(GLOBALS->expanderwindow);
 	}
 #endif
 
-panedwindow=gtk_hpaned_new();
+GLOBALS->panedwindow = panedwindow = gtk_hpaned_new();
+if(GLOBALS->panedwindow_size_cache)
+	{
+	gtk_paned_set_position(GTK_PANED(GLOBALS->panedwindow), GLOBALS->panedwindow_size_cache);
+	GLOBALS->panedwindow_size_cache = 0;
+	}
 
 #ifdef HAVE_PANED_PACK
 if(GLOBALS->paned_pack_semantics)
@@ -2148,7 +2367,7 @@ if(GLOBALS->logfile)
 
 activate_stems_reader(GLOBALS->stems_name);
 
-while (gtk_events_pending()) gtk_main_iteration();
+gtk_events_pending_gtk_main_iteration();
 
 if(1)	/* here in order to calculate window manager delta if present... window is completely rendered by here */
 	{
@@ -2164,25 +2383,13 @@ if(scriptfile)
 	scriptfile=NULL;
 	}
 
-#if !defined(_MSC_VER) && !defined(__MINGW32__)
-if(GLOBALS->rpc_id)
+#ifdef WAVE_HAVE_GCONF
+if(GLOBALS->loaded_file_type != MISSING_FILE)
 	{
-	GLOBALS->rpc_ctx = shmat(GLOBALS->rpc_id, NULL, 0);
-	if(GLOBALS->rpc_ctx)
-		{
-                if(memcmp(&GLOBALS->rpc_ctx->matchword, RPC_MATCHWORD, 4))
-                        {
-                        fprintf(stderr, "RPC shared memory ID matchword mismatch, exiting.\n");
-                        exit(255);
-                        }
-		}
-		else
-		{
-                fprintf(stderr, "Not a valid RPC shared memory ID for remote operation, exiting.\n");
-                exit(255);
-		}
+	if(!chdir_cache) { wave_gconf_client_set_string("/current/pwd", getenv("PWD")); }
+	wave_gconf_client_set_string("/current/dumpfile", GLOBALS->loaded_file_name);
+	wave_gconf_client_set_string("/current/savefile", GLOBALS->filesel_writesave);
 	}
-
 #endif
 
 #if !defined _MSC_VER
@@ -2363,7 +2570,11 @@ if(is_interactive)
 #endif
 	}
 
+#ifdef MAC_INTEGRATION
+exit(0); /* gtk_target_list_find crashes in OSX/Quartz is return instead of exit */
+#else
 return(0);
+#endif
 }
 
 void
@@ -2396,7 +2607,11 @@ set_window_size (int x, int y)
       if(!GLOBALS->socket_xid)
 #endif
 	{
+#ifdef MAC_INTEGRATION
+      	gtk_window_resize(GTK_WINDOW (GLOBALS->mainwindow), x, y);
+#else
       	gtk_window_set_default_size(GTK_WINDOW (GLOBALS->mainwindow), x, y);
+#endif
 	}
     }
 }
@@ -2430,7 +2645,11 @@ if(!GLOBALS->initial_window_get_valid)
 void 
 set_window_xypos(int root_x, int root_y)
 {
+#ifdef MAC_INTEGRATION
+if(GLOBALS->num_notebook_pages > 1) return;
+#else
 if(GLOBALS->xy_ignore_main_c_1) return;
+#endif
 
 #if !defined __MINGW32__ && !defined _MSC_VER
 GLOBALS->initial_window_xpos = root_x;
@@ -2647,9 +2866,31 @@ if(GLOBALS->stems_type != WAVE_ANNO_NONE)
 					else
 					{
 					char buf[64];
+#ifdef MAC_INTEGRATION
+					const gchar *p = quartz_application_get_executable_path();
+#endif
 					sprintf(buf, "%08x", shmid);
+
+#ifdef MAC_INTEGRATION
+					if(p && strstr(p, "Contents/"))
+						{
+						const char *xec = "../Resources/bin/rtlbrowse";
+						char *res = strdup_2(p);
+						char *slsh = strrchr(res, '/');
+						if(slsh)
+							{
+							*(slsh+1) = 0;
+							res = realloc_2(res, strlen(res) + strlen(xec) + 1);
+							strcat(res, xec);
+						        execlp(res, "rtlbrowse", buf, NULL);
+							fprintf(stderr, "GTKWAVE | Could not find '%s' in .app!\n", res);
+							free_2(res);
+							}
+						}
+#endif
 				        execlp("rtlbrowse", "rtlbrowse", buf, NULL);
-				        exit(0);        /* control never gets here if successful */
+					fprintf(stderr, "GTKWAVE | Could not find rtlbrowse executable, exiting!\n");
+				        exit(255); /* control never gets here if successful */
 					}
 				}
 			}
@@ -2730,7 +2971,26 @@ void optimize_vcd_file(void) {
         }					
       }
       else {
+#ifdef MAC_INTEGRATION
+	const gchar *p = quartz_application_get_executable_path();
+	if(p && strstr(p, "Contents/"))
+		{
+		const char *xec = "../Resources/bin/vcd2fst";
+		char *res = strdup_2(p);
+		char *slsh = strrchr(res, '/');
+		if(slsh)
+			{
+			*(slsh+1) = 0;
+			res = realloc_2(res, strlen(res) + strlen(xec) + 1);
+			strcat(res, xec);
+		        execlp(res, "vcd2fst", GLOBALS->unoptimized_vcd_file_name, buf, NULL);
+			fprintf(stderr, "GTKWAVE | Could not find '%s' in .app!\n", res);
+			free_2(res);
+			}
+		}
+#endif
         execlp("vcd2fst", "vcd2fst", GLOBALS->unoptimized_vcd_file_name, buf, NULL);
+	fprintf(stderr, "GTKWAVE | Could not find vcd2fst executable, exiting!\n");
 	exit(255);
       }
     }
@@ -2738,4 +2998,3 @@ void optimize_vcd_file(void) {
   }	
 }
 #endif
-
