@@ -25,7 +25,7 @@ i = ((int) (((long) which) & 31L)) % 26;
 GLOBALS->dirty_markerbox_c_1 = 1;
  
 entry_text = gtk_entry_get_text(GTK_ENTRY(entry));
-if(strlen(entry_text))
+if(entry_text && strlen(entry_text))
 	{
 	if(GLOBALS->shadow_marker_names[i])
 		{
@@ -53,7 +53,7 @@ i = ((int) (((long) which) & 31L)) % 26;
 GLOBALS->dirty_markerbox_c_1 = 1;
  
 entry_text = gtk_entry_get_text(GTK_ENTRY(entry));
-if(strlen(entry_text))
+if(entry_text && strlen(entry_text))
 	{
 	if(GLOBALS->shadow_marker_names[i])
 		{
@@ -92,6 +92,7 @@ ent_idx = ((int) (((long) which) & 31L)) % 26;
 entry=GLOBALS->entries_markerbox_c_1[ent_idx];
 
 entry_text = gtk_entry_get_text(GTK_ENTRY(entry));
+entry_text = entry_text ? entry_text : "";
 if(!strlen(entry_text)) goto failure;
 if(!isdigit((int)(unsigned char)entry_text[0])) goto failure;
 
@@ -134,6 +135,7 @@ ent_idx = ((int) (((long) which) & 31L)) % 26;
 entry=GLOBALS->entries_markerbox_c_1[ent_idx];
 
 entry_text = gtk_entry_get_text(GTK_ENTRY(entry));
+entry_text = entry_text ? entry_text : "";
 if(!strlen(entry_text)) goto failure;
 
 temp=unformat_time(entry_text, GLOBALS->time_dimension);
@@ -183,7 +185,7 @@ if(GLOBALS->dirty_markerbox_c_1)
         wavearea_configure_event(GLOBALS->wavearea, NULL);
 	}
 
-  gtk_grab_remove(GLOBALS->window_markerbox_c_4);
+  wave_gtk_grab_remove(GLOBALS->window_markerbox_c_4);
   gtk_widget_destroy(GLOBALS->window_markerbox_c_4);
   GLOBALS->window_markerbox_c_4 = NULL;
 
@@ -200,7 +202,7 @@ int i;
   	GLOBALS->shadow_marker_names[i] = NULL;
 	}
 
-  gtk_grab_remove(GLOBALS->window_markerbox_c_4);
+  wave_gtk_grab_remove(GLOBALS->window_markerbox_c_4);
   gtk_widget_destroy(GLOBALS->window_markerbox_c_4);
   GLOBALS->window_markerbox_c_4 = NULL;
 }
@@ -331,6 +333,6 @@ void markerbox(char *title, GtkSignalFunc func)
 
     gtk_container_add (GTK_CONTAINER (GLOBALS->window_markerbox_c_4), table); /* need this table to keep ok/cancel buttons from stretching! */
     gtk_widget_show(GLOBALS->window_markerbox_c_4);
-    gtk_grab_add(GLOBALS->window_markerbox_c_4);
+    wave_gtk_grab_add(GLOBALS->window_markerbox_c_4);
 }
 
