@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2011.
+ * Copyright (c) Tony Bybell 1999-2012.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -35,7 +35,6 @@ void menu_set_sensitive(void);
 int file_quit_cmd_callback (GtkWidget *widget, gpointer data);
 int set_wave_menu_accelerator(char *str);
 int execute_script(char *name, int dealloc_name);
-char *append_array_row(nptr n);
 
 struct stringchain_t
 {
@@ -43,6 +42,43 @@ struct stringchain_t *next;
 char *name;
 };
 
+#ifdef MAC_INTEGRATION
+#define WAVE_USE_MLIST_T
+#endif
+
+#ifdef WAVE_USE_MLIST_T
+typedef void    (*gtkwave_mlist_callback)  ();
+
+struct gtkwave_mlist_t
+{
+  gchar *path;
+  gchar *accelerator;
+
+  gtkwave_mlist_callback callback;
+  guint                  callback_action;
+
+  /* possible values:
+   * "<Item>"           -> create a simple item
+   * "<ToggleItem>"     -> create a toggle item
+   * "<Separator>"      -> create a separator
+   */
+  gchar          *item_type;
+
+  /* Extra data for some item types:
+   *  ImageItem  -> pointer to inlined pixbuf stream
+   *  StockItem  -> name of stock item
+   */
+  gconstpointer extra_data;
+};
+
+typedef struct gtkwave_mlist_t gtkwave_mlist_t;
+
+GtkWidget *alt_menu_top(GtkWidget *window);
+GtkWidget *alt_menu(gtkwave_mlist_t *mi, int nmenu_items, GtkWidget **wlist, GtkAccelGroup *accel, gboolean is_menubar);
+
+#else
+#define gtkwave_mlist_t GtkItemFactoryEntry
+#endif
 
 enum WV_MenuItems {
 WV_MENU_FONV,
@@ -344,7 +380,7 @@ void menu_help(gpointer null_data, guint callback_action, GtkWidget *widget);
 void menu_version(gpointer null_data, guint callback_action, GtkWidget *widget);
 void menu_toggle_group(gpointer null_data, guint callback_action, GtkWidget *widget);
 
-GtkItemFactoryEntry *retrieve_menu_items_array(int *num_items);
+gtkwave_mlist_t *retrieve_menu_items_array(int *num_items);
 
 void menu_read_stems_cleanup(GtkWidget *widget, gpointer data);
 void menu_new_viewer_tab_cleanup(GtkWidget *widget, gpointer data);
@@ -353,13 +389,16 @@ int menu_new_viewer_tab_cleanup_2(char *fname);
 
 void set_scale_to_time_dimension_toggles(void);
 
-/* These should eventually have error values */
-void write_save_helper(FILE *file);
-int read_save_helper(char *wname); /* -1 = error, 0+ = number of lines read */
-
 void SetTraceScrollbarRowValue(int row, unsigned center);
 
 bvptr combine_traces(int direction, Trptr single_trace_only);
 
+/* currently only for OSX to disable OSX menus when grabbed */
+void wave_gtk_grab_add(GtkWidget *w);
+void wave_gtk_grab_remove(GtkWidget *w);
+#ifdef MAC_INTEGRATION
+void osx_menu_sensitivity(gboolean tr);
+#endif
+
 #endif
 
