@@ -315,6 +315,13 @@ GLOBALS->paned_pack_semantics=atoi_64(str)?1:0;
 return(0);
 }
 
+int f_ignore_savefile_pane_pos(char *str)
+{
+DEBUG(printf("f_ignore_savefile_pane_pos(\"%s\")\n",str));
+GLOBALS->ignore_savefile_pane_pos=atoi_64(str)?1:0;
+return(0);
+}
+
 int f_ignore_savefile_pos(char *str)
 {
 DEBUG(printf("f_ignore_savefile_pos(\"%s\")\n",str));
@@ -790,6 +797,7 @@ static struct rc_entry rcitems[]=
 { "hier_grouping", f_hier_grouping },
 { "hier_max_level", f_hier_max_level },
 { "hpane_pack", f_hpane_pack },
+{ "ignore_savefile_pane_pos", f_ignore_savefile_pane_pos },
 { "ignore_savefile_pos", f_ignore_savefile_pos },
 { "ignore_savefile_size", f_ignore_savefile_size },
 { "initial_signal_window_width", f_initial_signal_window_width },
@@ -911,6 +919,7 @@ if(GLOBALS->possibly_use_rc_defaults) vanilla_rc();
 if((override_rc)&&((handle=fopen(override_rc,"rb"))))
 	{
 	/* good, we have a handle */
+	wave_gconf_client_set_string("/current/rcfile", override_rc);
 	}
 else
 #if !defined __MINGW32__ && !defined _MSC_VER
@@ -927,9 +936,14 @@ if(!(handle=fopen(rcname,"rb")))
 
 	if(!(handle=fopen(rcpath,"rb")))
 		{
+		wave_gconf_client_set_string("/current/rcfile", "");
 		errno=0;
 		return; /* no .rc file */
 		} 
+		else
+		{
+		wave_gconf_client_set_string("/current/rcfile", rcpath);
+		}
 	}
 #else
 if(!(handle=fopen(rcname,"rb")))		/* no concept of ~ in win32 */
@@ -949,10 +963,13 @@ if(!(handle=fopen(rcname,"rb")))		/* no concept of ~ in win32 */
         }
         if ((home == NULL) || (!(handle=fopen(rcpath,"rb")))) {
             /* printf("No rc file\n"); */
+	    wave_gconf_client_set_string("/current/rcfile", "");
   	    errno=0;
 	    if(GLOBALS->possibly_use_rc_defaults) vanilla_rc();
 	    return; /* no .rc file */
 	    }
+
+	wave_gconf_client_set_string("/current/rcfile", rcpath);
 	} 
 #endif
 
