@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2010.
+ * Copyright (c) Tony Bybell 1999-2012.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -15,7 +15,6 @@
 #include "pixmaps.h"
 #include "symbol.h"
 #include "debug.h"
-#include "wave_rpc.h"
 
 #undef FOCUS_DEBUG_MSGS
 
@@ -397,9 +396,13 @@ if(!GLOBALS || !GLOBALS->filter_entry || !event)
 	}
 	else
 	{
+#ifdef MAC_INTEGRATION
+	return (GTK_WIDGET_HAS_FOCUS(GLOBALS->filter_entry));
+#else
 	return (GTK_WIDGET_HAS_FOCUS(GLOBALS->filter_entry) && 
 	  !(event->state & GDK_CONTROL_MASK) &&
 	  !(event->state & GDK_MOD1_MASK));
+#endif
 	}
 }
 
@@ -424,6 +427,48 @@ if(GTK_WIDGET_HAS_FOCUS(GLOBALS->signalarea_event_box))
 	{
 	switch(event->keyval)
 		{
+#ifdef MAC_INTEGRATION
+		/* need to do this, otherwise if a menu accelerator it steals the key from gtk */
+		case GDK_a:
+		  if(event->state & GDK_MOD2_MASK)
+		    {
+		      menu_dataformat_highlight_all(NULL, 0, NULL);
+		      rc = TRUE;
+		    }
+		  break;
+
+		case GDK_A:
+		  if(event->state & GDK_MOD2_MASK)
+		    {
+		      menu_dataformat_unhighlight_all(NULL, 0, NULL);
+		      rc = TRUE;
+		    }
+		  break;
+
+		case GDK_x:
+		  if(event->state & GDK_MOD2_MASK)
+		    {
+		      menu_cut_traces(NULL, 0, NULL);
+		      rc = TRUE;
+		    }
+		  break;
+
+		case GDK_c:
+		  if(event->state & GDK_MOD2_MASK)
+		    {
+		      menu_copy_traces(NULL, 0, NULL);
+		      rc = TRUE;
+		    }
+		  break;
+
+		case GDK_v:
+		  if(event->state & GDK_MOD2_MASK)
+		    {
+		      menu_paste_traces(NULL, 0, NULL);
+		      rc = TRUE;
+		    }
+		  break;
+#endif
 		case GDK_Page_Up:
 		case GDK_KP_Page_Up:
 		case GDK_Page_Down:
@@ -535,7 +580,11 @@ if(GLOBALS->dnd_sigview)
 	      switch(event->keyval)
 		{
 		case GDK_a:
+#ifdef MAC_INTEGRATION
+		  if(event->state & GDK_META_MASK)
+#else
 		  if(event->state & GDK_CONTROL_MASK)
+#endif
 		    {
 		      treeview_select_all_callback();
 		      rc = TRUE;
@@ -543,7 +592,11 @@ if(GLOBALS->dnd_sigview)
 		  break;
 
 		case GDK_A:
+#ifdef MAC_INTEGRATION
+		  if(event->state & GDK_META_MASK)
+#else
 		  if(event->state & GDK_CONTROL_MASK)
+#endif
 		    {
 		      treeview_unselect_all_callback();
 		      rc = TRUE;
@@ -558,7 +611,11 @@ if(GLOBALS->dnd_sigview)
 	      switch(event->keyval)
 		{
 		case GDK_a:
+#ifdef MAC_INTEGRATION
+		  if(event->state & GDK_META_MASK)
+#else
 		  if(event->state & GDK_CONTROL_MASK)
+#endif
 		    {
 		      /* eat keystroke */
 		      rc = TRUE;
@@ -566,7 +623,11 @@ if(GLOBALS->dnd_sigview)
 		  break;
 
 		case GDK_A:
+#ifdef MAC_INTEGRATION
+		  if(event->state & GDK_META_MASK)
+#else
 		  if(event->state & GDK_CONTROL_MASK)
+#endif
 		    {
 		      /* eat keystroke */
 		      rc = TRUE;
@@ -610,6 +671,35 @@ scroll_event( GtkWidget * widget, GdkEventScroll * event )
 #endif
 
 
+#ifdef WAVE_ALLOW_QUARTZ_FLUSH_WORKAROUND
+#ifdef MAC_INTEGRATION
+static gboolean osx_timer(gpointer dummy)
+{
+if(GLOBALS)
+	{
+	if(GLOBALS->force_hide_show == 2)
+		{
+		if((GLOBALS->signalarea)&&(GLOBALS->wavearea))
+			{
+			gtk_widget_hide(GLOBALS->signalarea);
+			gtk_widget_show(GLOBALS->signalarea);
+			gtk_widget_hide(GLOBALS->wavearea);
+			gtk_widget_show(GLOBALS->wavearea);
+			}
+		}
+
+	if(GLOBALS->force_hide_show)
+		{
+		GLOBALS->force_hide_show--;
+		}
+	}
+
+return(TRUE);
+}
+#endif
+#endif
+
+
 static gboolean mouseover_timer(gpointer dummy)
 {
 static gboolean run_once = FALSE;
@@ -624,10 +714,21 @@ GdkEventMotion event[1];
 event[0].deviceid = GDK_CORE_POINTER;  
 #endif
 
-execute_rpc();
+if(in_main_iteration()) return(TRUE);
+
+if(GLOBALS->splash_is_loading)
+	{
+	return(TRUE);
+        }
+
+if(GLOBALS->splash_fix_win_title)
+	{
+	GLOBALS->splash_fix_win_title = 0;
+	wave_gtk_window_set_title(GTK_WINDOW(GLOBALS->mainwindow), GLOBALS->winname, GLOBALS->dumpfile_is_modified ? WAVE_SET_TITLE_MODIFIED: WAVE_SET_TITLE_NONE, 0);
+	}
 
 #ifdef WAVE_USE_GTK2
-#ifdef WAVE_GDK_QUARTZ
+#ifdef MAC_INTEGRATION
 if(GLOBALS->dnd_helper_quartz)
         {
         char *dhq = g_malloc(strlen(GLOBALS->dnd_helper_quartz)+1);
@@ -640,6 +741,43 @@ if(GLOBALS->dnd_helper_quartz)
 #endif   
 #endif
 
+#if defined(MAC_INTEGRATION) || defined(WAVE_HAVE_GCONF)
+if(process_finder_names_queued())
+	{
+	if(GLOBALS->pFileChoose)
+		{
+		if(!GLOBALS->window_simplereq_c_9)
+			{
+			char *qn = process_finder_extract_queued_name();
+			if(qn)
+				{
+				int qn_len = strlen(qn);
+				const int mlen = 30;
+				if(qn_len < mlen)
+					{
+					simplereqbox("File queued for loading",300,qn,"OK", NULL, NULL, 1);
+					}
+					else
+					{
+					char *qn_2 = wave_alloca(mlen + 4);
+					strcpy(qn_2, "...");
+					strcat(qn_2, qn + qn_len - mlen);
+					simplereqbox("File queued for loading",300,qn_2,"OK", NULL, NULL, 1);
+					}
+				return(TRUE);
+				}
+			}
+		}
+		else
+		{
+		if(process_finder_name_integration())
+			{
+			return(TRUE);
+			}
+		}
+	}
+#endif
+
 if(GLOBALS->loaded_file_type == MISSING_FILE)
 	{
 	return(TRUE);
@@ -651,7 +789,7 @@ if(run_once == FALSE) /* avoid any race conditions with the toolkit for uninitia
 	return(TRUE);
 	}
 
-if((!GLOBALS) || (!GLOBALS->signalarea) || (!GLOBALS->signalarea->window))                 
+if((!GLOBALS->signalarea) || (!GLOBALS->signalarea->window))                 
 	{
 	return(TRUE);
 	}
@@ -879,7 +1017,11 @@ if((GLOBALS->traces.visible)&&(GLOBALS->signalpixmap))
 
 	if(which>=GLOBALS->traces.visible)
 		{
+#ifdef MAC_INTEGRATION
+		if((event->state&(GDK_MOD2_MASK|GDK_SHIFT_MASK)) == (GDK_SHIFT_MASK))
+#else
 		if((event->state&(GDK_CONTROL_MASK|GDK_SHIFT_MASK)) == (GDK_SHIFT_MASK))
+#endif
 			{
 			/* ok for plain-vanilla shift click only */
 			which = GLOBALS->traces.visible-1;
@@ -915,7 +1057,12 @@ if((GLOBALS->traces.visible)&&(GLOBALS->signalpixmap))
 	                }
 	        }
 
+
+#ifdef MAC_INTEGRATION
+	if(event->state & GDK_MOD2_MASK)
+#else
 	if(event->state&GDK_CONTROL_MASK)
+#endif
 		{
 		if(t) /* scan-build */
 		  {
@@ -1046,6 +1193,15 @@ int width;
 
 if((!widget)||(!widget->window)) return(TRUE);
 
+#ifdef WAVE_ALLOW_QUARTZ_FLUSH_WORKAROUND
+#ifdef MAC_INTEGRATION
+if(!GLOBALS->force_hide_show)
+	{
+	GLOBALS->force_hide_show = 2;
+	}
+#endif
+#endif
+
 make_sigarea_gcs(widget);
 UpdateTracesVisible();
 
@@ -1335,6 +1491,11 @@ if(GLOBALS->use_standard_clicking)
 	gtkwave_signal_connect(GTK_OBJECT(GLOBALS->signalarea), "button_release_event", GTK_SIGNAL_FUNC(button_release_event_std), NULL);
 	gtkwave_signal_connect(GTK_OBJECT(GLOBALS->signalarea), "motion_notify_event",GTK_SIGNAL_FUNC(motion_notify_event_std), NULL);
 	g_timeout_add(100, mouseover_timer, NULL);
+#ifdef WAVE_ALLOW_QUARTZ_FLUSH_WORKAROUND
+#ifdef MAC_INTEGRATION
+	g_timeout_add(100, osx_timer, NULL);
+#endif
+#endif
 
 #ifdef WAVE_USE_GTK2
 	gtkwave_signal_connect(GTK_OBJECT(GLOBALS->signalarea), "scroll_event",GTK_SIGNAL_FUNC(scroll_event), NULL);
