@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2005.
+ * Copyright (c) Tony Bybell 1999-2012.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,7 +19,7 @@
 static void ok_callback(GtkWidget *widget, GtkWidget *nothing)
 {
   DEBUG(printf("OK\n"));
-  gtk_grab_remove(GLOBALS->window_simplereq_c_9);
+  wave_gtk_grab_remove(GLOBALS->window_simplereq_c_9);
   gtk_widget_destroy(GLOBALS->window_simplereq_c_9);
   GLOBALS->window_simplereq_c_9 = NULL;
   if(GLOBALS->cleanup)GLOBALS->cleanup(NULL,(gpointer)1);
@@ -28,7 +28,7 @@ static void ok_callback(GtkWidget *widget, GtkWidget *nothing)
 static void destroy_callback(GtkWidget *widget, GtkWidget *nothing)
 {
   DEBUG(printf("Cancel\n"));
-  gtk_grab_remove(GLOBALS->window_simplereq_c_9);
+  wave_gtk_grab_remove(GLOBALS->window_simplereq_c_9);
   gtk_widget_destroy(GLOBALS->window_simplereq_c_9);
   GLOBALS->window_simplereq_c_9 = NULL;
   if(GLOBALS->cleanup)GLOBALS->cleanup(NULL,NULL);
@@ -57,7 +57,7 @@ void simplereqbox(char *title, int width, char *default_text,
     install_focus_cb(GLOBALS->window_simplereq_c_9, ((char *)&GLOBALS->window_simplereq_c_9) - ((char *)GLOBALS));
 
     gtk_window_set_transient_for(GTK_WINDOW(GLOBALS->window_simplereq_c_9), GTK_WINDOW(GLOBALS->mainwindow));
-    gtk_widget_set_usize( GTK_WIDGET (GLOBALS->window_simplereq_c_9), width, 55 + 52);
+    gtk_widget_set_usize( GTK_WIDGET (GLOBALS->window_simplereq_c_9), width, 200);
     gtk_window_set_title(GTK_WINDOW (GLOBALS->window_simplereq_c_9), title);
     gtkwave_signal_connect(GTK_OBJECT (GLOBALS->window_simplereq_c_9), "delete_event",(GtkSignalFunc) destroy_callback, NULL);
     gtk_window_set_policy(GTK_WINDOW(GLOBALS->window_simplereq_c_9), FALSE, FALSE, FALSE);
@@ -108,6 +108,6 @@ void simplereqbox(char *title, int width, char *default_text,
 	}
 
     gtk_widget_show(GLOBALS->window_simplereq_c_9);
-    gtk_grab_add(GLOBALS->window_simplereq_c_9);
+    wave_gtk_grab_add(GLOBALS->window_simplereq_c_9);
 }
 
