@@ -108,9 +108,6 @@ struct Bits *makevec(char *, char *);
 struct Bits *makevec_annotated(char *, char *);
 int maketraces(char *, char *, int);
 
-int parsewavline(char *, char *, int);
-int parsewavline_lx2(char *, char *, int);
-
 
 /* additions to bitvec.c because of search.c/menu.c ==> formerly in analyzer.h */
 bvptr bits2vector(struct Bits *b);
@@ -125,6 +122,7 @@ char *makename_chain(struct symbol *sym);
 /* splash screen activation (version >= GTK2 only) */
 void splash_create(void);
 void splash_sync(off_t current, off_t total);  
+void splash_finalize(void);
 
 /* accessor functions for sym->selected moved (potentially) to sparse array */
 char get_s_selected(struct symbol *s);
