@@ -1,5 +1,5 @@
 /*
- * Copyright (c) Tony Bybell and Concept Engineering GmbH 2008-2011.
+ * Copyright (c) Tony Bybell and Concept Engineering GmbH 2008-2012.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -883,6 +883,9 @@ if(!list)
 	{
 	return(0);
 	}
+
+read_save_helper_relative_init(NULL); /* should be passing canonicalized filter names here...so no need for relative processing */
+
 s_new_list = calloc_2(c, sizeof(char *));
 match_idx_list = calloc_2(c, sizeof(int *));
 match_type_list = calloc_2(c, sizeof(int *));
@@ -2224,6 +2227,11 @@ if(dot)
 		ftype = WAVE_FTYPE_SAVEFILE;
 		}
 	else
+	if(!strcasecmp("gtkw", dot+1))
+		{
+		ftype = WAVE_FTYPE_SAVEFILE;
+		}
+	else
 	if(!strcasecmp("stems", dot+1))
 		{
 		ftype = WAVE_FTYPE_STEMSFILE;
@@ -2312,8 +2320,13 @@ switch(ftype)
         	if(*GLOBALS->fileselbox_text) free_2(*GLOBALS->fileselbox_text);
         	*GLOBALS->fileselbox_text=(char *)strdup_2(s);
 
+#ifndef MAC_INTEGRATION
 		GLOBALS->block_xy_update = 1;
-		read_save_helper(s);
+#else
+		GLOBALS->block_xy_update = (GLOBALS->num_notebook_pages > 1); /* let window always resize if 1 tab */
+#endif
+		wave_gconf_client_set_string("/current/savefile", s);
+		read_save_helper(s, NULL, NULL, NULL, NULL);
 		GLOBALS->block_xy_update = 0;
 		rc = 1;
 		break;
@@ -2556,7 +2569,7 @@ g_timeout_add(atoi(WAVE_TCLCB_TIMER_PERIOD_INIT), setvar_timer, (gpointer)interp
 
 static int menu_func(ClientData clientData, Tcl_Interp *interp, int objc, Tcl_Obj *CONST objv[])
 {
-GtkItemFactoryEntry *ife = (GtkItemFactoryEntry *)clientData;
+gtkwave_mlist_t *ife = (gtkwave_mlist_t *)clientData;
 int i;
 struct wave_script_args *old_wave_script_args = GLOBALS->wave_script_args; /* stackable args */
 char fexit = GLOBALS->enable_fast_exit;
@@ -2591,6 +2604,8 @@ GLOBALS->enable_fast_exit = 1;
 
 if(objc > 1)
 	{
+	struct wave_script_args *wc = NULL;
+
 	for(i=1;i<objc;i++)
 		{
 		char *s = Tcl_GetString(objv[i]);
@@ -2603,11 +2618,21 @@ if(objc > 1)
 			}
 		w->curr = NULL; /* yes, curr is only ever used for the 1st struct, but there is no sense creating head/follower structs for this */
 		w->next = NULL;
+
 		if(!GLOBALS->wave_script_args)
 			{
 			GLOBALS->wave_script_args = w;
 			w->curr = w;
 			}
+			else
+			{
+			if(wc)	/* scan-build: suppress warning, this will never happen */
+				{
+				wc->next = w; /* we later really traverse through curr->next from the head pointer */
+				}
+			}
+
+		wc = w;
 		}
 
 	if(!GLOBALS->wave_script_args) /* create a dummy list in order to keep requesters from popping up in file.c, etc. */
@@ -2688,7 +2713,7 @@ void gtkUpdate(ClientData ignore)
 int  gtkwaveInterpreterInit(Tcl_Interp *interp) {
   int i;
   char commandName[128];
-  GtkItemFactoryEntry *ife;
+  gtkwave_mlist_t *ife;
   int num_menu_items;
 
 #ifdef WAVE_TCL_STUBIFY
@@ -2828,7 +2853,7 @@ void make_tcl_interpreter(char *argv[])
 {
   int i;
   char commandName[32768];
-  GtkItemFactoryEntry *ife;
+  gtkwave_mlist_t *ife;
   int num_menu_items;
   int n = 0;
   
