@@ -391,11 +391,25 @@ static void tree_expand_callback(GtkCTree *ctree, GtkCTreeNode *node, gpointer u
 {
 create_sst_nodes_if_necessary(node);
 generic_tree_expand_collapse_callback(1, node);
+#ifdef WAVE_ALLOW_QUARTZ_FLUSH_WORKAROUND
+#ifdef MAC_INTEGRATION
+/* workaround for ctree not rendering properly in OSX */
+gtk_widget_hide(GTK_WIDGET(GLOBALS->tree_treesearch_gtk2_c_1));
+gtk_widget_show(GTK_WIDGET(GLOBALS->tree_treesearch_gtk2_c_1));
+#endif
+#endif
 }
  
 static void tree_collapse_callback(GtkCTree *ctree, GtkCTreeNode *node, gpointer user_data) 
 {
 generic_tree_expand_collapse_callback(0, node);
+#ifdef WAVE_ALLOW_QUARTZ_FLUSH_WORKAROUND
+#ifdef MAC_INTEGRATION
+/* workaround for ctree not rendering properly in OSX */
+gtk_widget_hide(GTK_WIDGET(GLOBALS->tree_treesearch_gtk2_c_1));
+gtk_widget_show(GTK_WIDGET(GLOBALS->tree_treesearch_gtk2_c_1));
+#endif
+#endif
 }
 
 
@@ -537,6 +551,10 @@ if(GLOBALS->selected_hierarchy_name)
 	}
 
 t=(struct tree *)gtk_clist_get_row_data(GTK_CLIST(GLOBALS->ctree_main), row);
+if(t)
+	{
+	/* unused */
+	}
 DEBUG(printf("TU: %08x %s\n",t,t->name));
  GLOBALS->sig_root_treesearch_gtk2_c_1 = GLOBALS->treeroot;
  fill_sig_store ();
@@ -613,11 +631,12 @@ static void enter_callback_e(GtkWidget *widget, GtkWidget *nothing)
   G_CONST_RETURN gchar *entry_text;
   int len;
   entry_text = gtk_entry_get_text(GTK_ENTRY(GLOBALS->entry_a_treesearch_gtk2_c_2));
+  entry_text = entry_text ? entry_text : "";
   DEBUG(printf("Entry contents: %s\n", entry_text));
   if(!(len=strlen(entry_text))) GLOBALS->entrybox_text_local_treesearch_gtk2_c_3=NULL;
 	else strcpy((GLOBALS->entrybox_text_local_treesearch_gtk2_c_3=(char *)malloc_2(len+1)),entry_text);
 
-  gtk_grab_remove(GLOBALS->window1_treesearch_gtk2_c_3);
+  wave_gtk_grab_remove(GLOBALS->window1_treesearch_gtk2_c_3);
   gtk_widget_destroy(GLOBALS->window1_treesearch_gtk2_c_3);
   GLOBALS->window1_treesearch_gtk2_c_3 = NULL;
 
@@ -628,7 +647,7 @@ static void destroy_callback_e(GtkWidget *widget, GtkWidget *nothing)
 {
   DEBUG(printf("Entry Cancel\n"));
   GLOBALS->entrybox_text_local_treesearch_gtk2_c_3=NULL;
-  gtk_grab_remove(GLOBALS->window1_treesearch_gtk2_c_3);
+  wave_gtk_grab_remove(GLOBALS->window1_treesearch_gtk2_c_3);
   gtk_widget_destroy(GLOBALS->window1_treesearch_gtk2_c_3);
   GLOBALS->window1_treesearch_gtk2_c_3 = NULL;
 }
@@ -679,7 +698,7 @@ static void entrybox_local(char *title, int width, char *default_text, int maxch
     gtk_container_add (GTK_CONTAINER (hbox), button2);
 
     gtk_widget_show(GLOBALS->window1_treesearch_gtk2_c_3);
-    gtk_grab_add(GLOBALS->window1_treesearch_gtk2_c_3);
+    wave_gtk_grab_add(GLOBALS->window1_treesearch_gtk2_c_3);
 }
 
 /***************************************************************************/
@@ -1493,6 +1512,11 @@ GtkWidget* treeboxframe(char *title, GtkSignalFunc func)
 
     vpan = gtk_vpaned_new (); /* GLOBALS->sst_vpaned is to be used to clone position over during reload */
     GLOBALS->sst_vpaned = (GtkPaned *)vpan;
+    if(GLOBALS->vpanedwindow_size_cache)
+	{
+	gtk_paned_set_position(GTK_PANED(GLOBALS->sst_vpaned), GLOBALS->vpanedwindow_size_cache);    
+	GLOBALS->vpanedwindow_size_cache = 0;
+	}
     gtk_widget_show (vpan);
     gtk_box_pack_start (GTK_BOX (vbox), vpan, TRUE, TRUE, 1);
 
@@ -2057,6 +2081,10 @@ static void DNDDataReceivedCB(
     /* Source and target widgets are the same? */
     source_widget = gtk_drag_get_source_widget(dc);
     same = (source_widget == widget) ? TRUE : FALSE;
+    if(same)
+	{
+	/* unused */
+	}
 
     if(source_widget)
     if((source_widget == GLOBALS->clist_search_c_3) || /* from search */
@@ -2093,7 +2121,7 @@ static void DNDDataReceivedCB(
        (info == WAVE_DRAG_TAR_INFO_2))
     {
     /* printf("XXX %08x '%s'\n", selection_data->data, selection_data->data); */
-#ifndef WAVE_GDK_QUARTZ
+#ifndef MAC_INTEGRATION
     DND_helper_quartz((char *)selection_data->data);
 #else
     if(!GLOBALS->dnd_helper_quartz)
@@ -2109,17 +2137,33 @@ void DND_helper_quartz(char *data)
 {
 int num_found;
 
-if(!(num_found = process_url_list(data)))
-        {
-        num_found = process_tcl_list(data, TRUE);
-        }
+if(!GLOBALS->splash_is_loading)
+	{
+#if GTK_CHECK_VERSION(2,4,0)
+	if(!GLOBALS->pFileChoose)
+#endif
+		{
+		if(!(num_found = process_url_list(data)))
+		        {
+		        num_found = process_tcl_list(data, TRUE);
+		        }
 
-if(num_found)
-        {
-        MaxSignalLength();
-        signalarea_configure_event(GLOBALS->signalarea, NULL);
-        wavearea_configure_event(GLOBALS->wavearea, NULL);
-        }
+		if(num_found)
+		        {
+		        MaxSignalLength();
+		        signalarea_configure_event(GLOBALS->signalarea, NULL);
+		        wavearea_configure_event(GLOBALS->wavearea, NULL);
+		        }
+		}
+#if GTK_CHECK_VERSION(2,4,0)
+		else
+		{
+	        MaxSignalLength();
+	        signalarea_configure_event(GLOBALS->signalarea, NULL);
+	        wavearea_configure_event(GLOBALS->wavearea, NULL);
+		}
+#endif
+	}
 }
 
 
