@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) Tony Bybell 1999-2011.
+ * Copyright (c) Tony Bybell 1999-2012.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -2524,8 +2524,6 @@ if(GLOBALS->yytext_vcd_c_1)
 
 TimeType vcd_main(char *fname)
 {
-int flen;
-
 GLOBALS->pv_vcd_c_1=GLOBALS->rootv_vcd_c_1=NULL;
 GLOBALS->vcd_hier_delimeter[0]=GLOBALS->hier_delimeter;
 
@@ -2538,9 +2536,7 @@ if(!GLOBALS->hier_was_explicitly_set) /* set default hierarchy split char */
 	GLOBALS->hier_delimeter='.';
 	}
 
-flen=strlen(fname);
-if (((flen>2)&&(!strcmp(fname+flen-3,".gz")))||
-   ((flen>3)&&(!strcmp(fname+flen-4,".zip"))))
+if(suffix_check(fname, ".gz") || suffix_check(fname, ".zip"))
 	{
 	char *str;
 	int dlen;
@@ -2660,6 +2656,7 @@ if(GLOBALS->blackout_regions)
 
 GLOBALS->is_vcd=~0;
 
+/* SPLASH */                            splash_finalize();
 return(GLOBALS->max_time);
 }
 
