@@ -531,9 +531,8 @@ for(GLOBALS->yytext_vcd_partial_c_2[len++]=ch;;GLOBALS->yytext_vcd_partial_c_2[l
 	ch=getch();
         if(ch==' ')
                 {
-                signed char ch2;
                 if(match_kw) break;
-                if((ch2 = getch_peek()) == '[')
+                if(getch_peek() == '[')
                         {
                         ch = getch();
                         GLOBALS->varsplit_vcd_partial_c_2=GLOBALS->yytext_vcd_partial_c_2+len; /* keep looping so we get the *last* one */
@@ -624,14 +623,14 @@ static void sync_end(char *hdr)
 {
 int tok;
 
-if(hdr) DEBUG(fprintf(stderr,"%s",hdr));
+if(hdr) { DEBUG(fprintf(stderr,"%s",hdr)); }
 for(;;)
 	{
 	tok=get_token();
 	if((tok==T_END)||(tok==T_EOF)) break;
-	if(hdr)DEBUG(fprintf(stderr," %s",GLOBALS->yytext_vcd_partial_c_2));
+	if(hdr) { DEBUG(fprintf(stderr," %s",GLOBALS->yytext_vcd_partial_c_2)); }
 	}
-if(hdr) DEBUG(fprintf(stderr,"\n"));
+if(hdr) { DEBUG(fprintf(stderr,"\n")); }
 }
 
 static int version_sync_end(char *hdr)
@@ -639,19 +638,19 @@ static int version_sync_end(char *hdr)
 int tok;
 int rc = 0;
 
-if(hdr) DEBUG(fprintf(stderr,"%s",hdr));
+if(hdr) { DEBUG(fprintf(stderr,"%s",hdr)); }
 for(;;)
 	{
 	tok=get_token();
 	if((tok==T_END)||(tok==T_EOF)) break;
-	if(hdr)DEBUG(fprintf(stderr," %s",GLOBALS->yytext_vcd_partial_c_2));
+	if(hdr) { DEBUG(fprintf(stderr," %s",GLOBALS->yytext_vcd_partial_c_2)); }
         if(strstr(GLOBALS->yytext_vcd_partial_c_2, "Icarus"))   /* turn off autocoalesce for Icarus */
                 {
 		GLOBALS->autocoalesce = 0;
                 rc = 1;
                 }
 	}
-if(hdr) DEBUG(fprintf(stderr,"\n"));
+if(hdr) { DEBUG(fprintf(stderr,"\n")); }
 return(rc);
 }
 
@@ -661,7 +660,7 @@ static void parse_valuechange(void)
 struct vcdsymbol *v;
 char *vector;
 int vlen;
-hptr hsuf;
+/* hptr hsuf; */ /* scan-build */
 
 switch(GLOBALS->yytext_vcd_partial_c_2[0])
 	{
@@ -687,7 +686,7 @@ switch(GLOBALS->yytext_vcd_partial_c_2[0])
 				DEBUG(fprintf(stderr,"%s = '%c'\n",v->name,v->value[0]));
 
 				v->narray[0]->curr = v->app_array[0];
-				hsuf = add_histent_p(GLOBALS->current_time_vcd_partial_c_2,v->narray[0],v->value[0],1, NULL);
+				/* hsuf = */ add_histent_p(GLOBALS->current_time_vcd_partial_c_2,v->narray[0],v->value[0],1, NULL); /* scan-build */
 				v->app_array[0] = v->narray[0]->curr;
 				v->narray[0]->curr->next = v->tr_array[0];
 				if(v->narray[0]->harray) { free_2(v->narray[0]->harray); v->narray[0]->harray = NULL; }
@@ -1018,7 +1017,7 @@ int disable_autocoalesce = 0;
 
 for(;;)
 	{
-	switch(tok=get_token())
+	switch(get_token())
 		{
 		case T_COMMENT:
 			sync_end("COMMENT:");
@@ -1981,7 +1980,7 @@ struct sym_chain *sym_chain=NULL, *sym_curr=NULL;
 int duphier=0;
 char hashdirty;
 struct vcdsymbol *v, *vprime;
-char *str = NULL;
+char *str = wave_alloca(1); /* quiet scan-build null pointer warning below */
 #ifdef _WAVE_HAVE_JUDY
 int ss_len, longest = 0;
 #endif
@@ -2389,6 +2388,7 @@ if(!nd->harray)         /* make quick array lookup for aet display */
                 fprintf( stderr, "Out of memory, can't add %s to analyzer\n",
                         nd->nname );
                 free_2(t);
+		return; /* scan-build : really can't do anything here */
                 }
         
         histpnt=&(nd->head);
